from _typeshed import Incomplete

class DecimalPlaces:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, is_enforced: Incomplete | None = None, digits: Incomplete | None = None) -> None: ...
    @property
    def is_enforced(self): ...
    @is_enforced.setter
    def is_enforced(self, is_enforced) -> None: ...
    @property
    def digits(self): ...
    @digits.setter
    def digits(self, digits) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Query:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        extern: Incomplete | None = None,
        query: Incomplete | None = None,
        type: Incomplete | None = None,
        params: Incomplete | None = None,
        dialect: Incomplete | None = None,
        now: Incomplete | None = None,
    ) -> None: ...
    @property
    def extern(self): ...
    @extern.setter
    def extern(self, extern) -> None: ...
    @property
    def query(self): ...
    @query.setter
    def query(self, query) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def params(self): ...
    @params.setter
    def params(self, params) -> None: ...
    @property
    def dialect(self): ...
    @dialect.setter
    def dialect(self, dialect) -> None: ...
    @property
    def now(self): ...
    @now.setter
    def now(self, now) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



import logging
from _typeshed import Incomplete
from collections.abc import Iterable
from enum import Enum
from types import TracebackType
from typing import Any
from typing_extensions import Self, TypeAlias

from influxdb_client.client._base import _BaseWriteApi
from influxdb_client.client.write.point import Point
from influxdb_client.domain.write_precision import _WritePrecision

_DataClass: TypeAlias = Any  # any dataclass
_NamedTuple: TypeAlias = tuple[Any, ...]  # any NamedTuple
_Observable: TypeAlias = Any  # reactivex.Observable

logger: logging.Logger

class WriteType(Enum):
    batching: int
    asynchronous: int
    synchronous: int

class WriteOptions:
    write_type: WriteType
    batch_size: int
    flush_interval: int
    jitter_interval: int
    retry_interval: int
    max_retries: int
    max_retry_delay: int
    max_retry_time: int
    exponential_base: int
    write_scheduler: Incomplete
    max_close_wait: int
    def __init__(
        self,
        write_type: WriteType = ...,
        batch_size: int = 1_000,
        flush_interval: int = 1_000,
        jitter_interval: int = 0,
        retry_interval: int = 5_000,
        max_retries: int = 5,
        max_retry_delay: int = 125_000,
        max_retry_time: int = 180_000,
        exponential_base: int = 2,
        max_close_wait: int = 300_000,
        write_scheduler=...,
    ) -> None: ...
    def to_retry_strategy(self, **kwargs): ...

SYNCHRONOUS: Incomplete
ASYNCHRONOUS: Incomplete

class PointSettings:
    defaultTags: Incomplete
    def __init__(self, **default_tags) -> None: ...
    def add_default_tag(self, key, value) -> None: ...

class _BatchItemKey:
    bucket: Incomplete
    org: Incomplete
    precision: Incomplete
    def __init__(self, bucket, org, precision="ns") -> None: ...
    def __hash__(self) -> int: ...
    def __eq__(self, o: object) -> bool: ...

class _BatchItem:
    key: Incomplete
    data: Incomplete
    size: Incomplete
    def __init__(self, key: _BatchItemKey, data, size: int = 1) -> None: ...
    def to_key_tuple(self) -> tuple[str, str, str]: ...

class _BatchResponse:
    data: Incomplete
    exception: Incomplete
    def __init__(self, data: _BatchItem, exception: Exception | None = None) -> None: ...

class WriteApi(_BaseWriteApi):
    def __init__(
        self, influxdb_client, write_options: WriteOptions = ..., point_settings: PointSettings = ..., **kwargs
    ) -> None: ...
    def write(
        self,
        bucket: str,
        org: str | None = None,
        record: str
        | Iterable[str]
        | Point
        | Iterable[Point]
        | dict[Incomplete, Incomplete]
        | Iterable[dict[Incomplete, Incomplete]]
        | bytes
        | Iterable[bytes]
        | _Observable
        | _NamedTuple
        | Iterable[_NamedTuple]
        | _DataClass
        | Iterable[_DataClass] = None,
        write_precision: _WritePrecision = "ns",
        **kwargs,
    ) -> Any: ...
    def flush(self) -> None: ...
    def close(self) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> None: ...
    def __del__(self) -> None: ...



from _typeshed import Incomplete

class DashboardQuery:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        text: Incomplete | None = None,
        edit_mode: Incomplete | None = None,
        name: Incomplete | None = None,
        builder_config: Incomplete | None = None,
    ) -> None: ...
    @property
    def text(self): ...
    @text.setter
    def text(self, text) -> None: ...
    @property
    def edit_mode(self): ...
    @edit_mode.setter
    def edit_mode(self, edit_mode) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def builder_config(self): ...
    @builder_config.setter
    def builder_config(self, builder_config) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Axes:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, x: Incomplete | None = None, y: Incomplete | None = None) -> None: ...
    @property
    def x(self): ...
    @x.setter
    def x(self, x) -> None: ...
    @property
    def y(self): ...
    @y.setter
    def y(self, y) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from datetime import datetime

from influxdb_client import Organization
from influxdb_client.client._base import _BaseDeleteApi

class DeleteApiAsync(_BaseDeleteApi):
    def __init__(self, influxdb_client) -> None: ...
    async def delete(
        self, start: str | datetime, stop: str | datetime, predicate: str, bucket: str, org: str | Organization | None = None
    ) -> bool: ...



from _typeshed import Incomplete

class FluxSuggestion:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, name: Incomplete | None = None, params: Incomplete | None = None) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def params(self): ...
    @params.setter
    def params(self, params) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class OrganizationsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_orgs_id(self, org_id, **kwargs): ...
    def delete_orgs_id_with_http_info(self, org_id, **kwargs): ...
    async def delete_orgs_id_async(self, org_id, **kwargs): ...
    def delete_orgs_id_members_id(self, user_id, org_id, **kwargs): ...
    def delete_orgs_id_members_id_with_http_info(self, user_id, org_id, **kwargs): ...
    async def delete_orgs_id_members_id_async(self, user_id, org_id, **kwargs): ...
    def delete_orgs_id_owners_id(self, user_id, org_id, **kwargs): ...
    def delete_orgs_id_owners_id_with_http_info(self, user_id, org_id, **kwargs): ...
    async def delete_orgs_id_owners_id_async(self, user_id, org_id, **kwargs): ...
    def get_orgs(self, **kwargs): ...
    def get_orgs_with_http_info(self, **kwargs): ...
    async def get_orgs_async(self, **kwargs): ...
    def get_orgs_id(self, org_id, **kwargs): ...
    def get_orgs_id_with_http_info(self, org_id, **kwargs): ...
    async def get_orgs_id_async(self, org_id, **kwargs): ...
    def get_orgs_id_members(self, org_id, **kwargs): ...
    def get_orgs_id_members_with_http_info(self, org_id, **kwargs): ...
    async def get_orgs_id_members_async(self, org_id, **kwargs): ...
    def get_orgs_id_owners(self, org_id, **kwargs): ...
    def get_orgs_id_owners_with_http_info(self, org_id, **kwargs): ...
    async def get_orgs_id_owners_async(self, org_id, **kwargs): ...
    def patch_orgs_id(self, org_id, patch_organization_request, **kwargs): ...
    def patch_orgs_id_with_http_info(self, org_id, patch_organization_request, **kwargs): ...
    async def patch_orgs_id_async(self, org_id, patch_organization_request, **kwargs): ...
    def post_orgs(self, post_organization_request, **kwargs): ...
    def post_orgs_with_http_info(self, post_organization_request, **kwargs): ...
    async def post_orgs_async(self, post_organization_request, **kwargs): ...
    def post_orgs_id_members(self, org_id, add_resource_member_request_body, **kwargs): ...
    def post_orgs_id_members_with_http_info(self, org_id, add_resource_member_request_body, **kwargs): ...
    async def post_orgs_id_members_async(self, org_id, add_resource_member_request_body, **kwargs): ...
    def post_orgs_id_owners(self, org_id, add_resource_member_request_body, **kwargs): ...
    def post_orgs_id_owners_with_http_info(self, org_id, add_resource_member_request_body, **kwargs): ...
    async def post_orgs_id_owners_async(self, org_id, add_resource_member_request_body, **kwargs): ...



from _typeshed import Incomplete

from influxdb_client import Bucket

class BucketsApi:
    def __init__(self, influxdb_client) -> None: ...
    def create_bucket(
        self,
        bucket: Incomplete | None = None,
        bucket_name: Incomplete | None = None,
        org_id: Incomplete | None = None,
        retention_rules: Incomplete | None = None,
        description: Incomplete | None = None,
        org: Incomplete | None = None,
    ) -> Bucket: ...
    def update_bucket(self, bucket: Bucket) -> Bucket: ...
    def delete_bucket(self, bucket): ...
    def find_bucket_by_id(self, id): ...
    def find_bucket_by_name(self, bucket_name): ...
    def find_buckets(self, **kwargs): ...



from influxdb_client.client.authorizations_api import AuthorizationsApi as AuthorizationsApi
from influxdb_client.client.bucket_api import BucketsApi as BucketsApi
from influxdb_client.client.delete_api import DeleteApi as DeleteApi
from influxdb_client.client.influxdb_client import InfluxDBClient as InfluxDBClient
from influxdb_client.client.invokable_scripts_api import InvokableScriptsApi as InvokableScriptsApi
from influxdb_client.client.labels_api import LabelsApi as LabelsApi
from influxdb_client.client.logging_handler import InfluxLoggingHandler as InfluxLoggingHandler
from influxdb_client.client.organizations_api import OrganizationsApi as OrganizationsApi
from influxdb_client.client.query_api import QueryApi as QueryApi
from influxdb_client.client.tasks_api import TasksApi as TasksApi
from influxdb_client.client.users_api import UsersApi as UsersApi
from influxdb_client.client.write.point import Point as Point
from influxdb_client.client.write_api import WriteApi as WriteApi, WriteOptions as WriteOptions
from influxdb_client.configuration import Configuration as Configuration
from influxdb_client.domain.add_resource_member_request_body import AddResourceMemberRequestBody as AddResourceMemberRequestBody
from influxdb_client.domain.analyze_query_response import AnalyzeQueryResponse as AnalyzeQueryResponse
from influxdb_client.domain.analyze_query_response_errors import AnalyzeQueryResponseErrors as AnalyzeQueryResponseErrors
from influxdb_client.domain.array_expression import ArrayExpression as ArrayExpression
from influxdb_client.domain.ast_response import ASTResponse as ASTResponse
from influxdb_client.domain.authorization import Authorization as Authorization
from influxdb_client.domain.authorization_post_request import AuthorizationPostRequest as AuthorizationPostRequest
from influxdb_client.domain.authorization_update_request import AuthorizationUpdateRequest as AuthorizationUpdateRequest
from influxdb_client.domain.authorizations import Authorizations as Authorizations
from influxdb_client.domain.axes import Axes as Axes
from influxdb_client.domain.axis import Axis as Axis
from influxdb_client.domain.axis_scale import AxisScale as AxisScale
from influxdb_client.domain.bad_statement import BadStatement as BadStatement
from influxdb_client.domain.band_view_properties import BandViewProperties as BandViewProperties
from influxdb_client.domain.binary_expression import BinaryExpression as BinaryExpression
from influxdb_client.domain.block import Block as Block
from influxdb_client.domain.boolean_literal import BooleanLiteral as BooleanLiteral
from influxdb_client.domain.bucket import Bucket as Bucket
from influxdb_client.domain.bucket_links import BucketLinks as BucketLinks
from influxdb_client.domain.bucket_metadata_manifest import BucketMetadataManifest as BucketMetadataManifest
from influxdb_client.domain.bucket_retention_rules import BucketRetentionRules as BucketRetentionRules
from influxdb_client.domain.bucket_shard_mapping import BucketShardMapping as BucketShardMapping
from influxdb_client.domain.buckets import Buckets as Buckets
from influxdb_client.domain.builder_aggregate_function_type import BuilderAggregateFunctionType as BuilderAggregateFunctionType
from influxdb_client.domain.builder_config import BuilderConfig as BuilderConfig
from influxdb_client.domain.builder_config_aggregate_window import BuilderConfigAggregateWindow as BuilderConfigAggregateWindow
from influxdb_client.domain.builder_functions_type import BuilderFunctionsType as BuilderFunctionsType
from influxdb_client.domain.builder_tags_type import BuilderTagsType as BuilderTagsType
from influxdb_client.domain.builtin_statement import BuiltinStatement as BuiltinStatement
from influxdb_client.domain.call_expression import CallExpression as CallExpression
from influxdb_client.domain.cell import Cell as Cell
from influxdb_client.domain.cell_links import CellLinks as CellLinks
from influxdb_client.domain.cell_update import CellUpdate as CellUpdate
from influxdb_client.domain.cell_with_view_properties import CellWithViewProperties as CellWithViewProperties
from influxdb_client.domain.check import Check as Check
from influxdb_client.domain.check_base import CheckBase as CheckBase
from influxdb_client.domain.check_base_links import CheckBaseLinks as CheckBaseLinks
from influxdb_client.domain.check_discriminator import CheckDiscriminator as CheckDiscriminator
from influxdb_client.domain.check_patch import CheckPatch as CheckPatch
from influxdb_client.domain.check_status_level import CheckStatusLevel as CheckStatusLevel
from influxdb_client.domain.check_view_properties import CheckViewProperties as CheckViewProperties
from influxdb_client.domain.checks import Checks as Checks
from influxdb_client.domain.column_data_type import ColumnDataType as ColumnDataType
from influxdb_client.domain.column_semantic_type import ColumnSemanticType as ColumnSemanticType
from influxdb_client.domain.conditional_expression import ConditionalExpression as ConditionalExpression
from influxdb_client.domain.config import Config as Config
from influxdb_client.domain.constant_variable_properties import ConstantVariableProperties as ConstantVariableProperties
from influxdb_client.domain.create_cell import CreateCell as CreateCell
from influxdb_client.domain.create_dashboard_request import CreateDashboardRequest as CreateDashboardRequest
from influxdb_client.domain.custom_check import CustomCheck as CustomCheck
from influxdb_client.domain.dashboard import Dashboard as Dashboard
from influxdb_client.domain.dashboard_color import DashboardColor as DashboardColor
from influxdb_client.domain.dashboard_query import DashboardQuery as DashboardQuery
from influxdb_client.domain.dashboard_with_view_properties import DashboardWithViewProperties as DashboardWithViewProperties
from influxdb_client.domain.dashboards import Dashboards as Dashboards
from influxdb_client.domain.date_time_literal import DateTimeLiteral as DateTimeLiteral
from influxdb_client.domain.dbr_ps import DBRPs as DBRPs
from influxdb_client.domain.dbrp import DBRP as DBRP
from influxdb_client.domain.dbrp_create import DBRPCreate as DBRPCreate
from influxdb_client.domain.dbrp_get import DBRPGet as DBRPGet
from influxdb_client.domain.dbrp_update import DBRPUpdate as DBRPUpdate
from influxdb_client.domain.deadman_check import DeadmanCheck as DeadmanCheck
from influxdb_client.domain.decimal_places import DecimalPlaces as DecimalPlaces
from influxdb_client.domain.delete_predicate_request import DeletePredicateRequest as DeletePredicateRequest
from influxdb_client.domain.dialect import Dialect as Dialect
from influxdb_client.domain.dict_expression import DictExpression as DictExpression
from influxdb_client.domain.dict_item import DictItem as DictItem
from influxdb_client.domain.duration import Duration as Duration
from influxdb_client.domain.duration_literal import DurationLiteral as DurationLiteral
from influxdb_client.domain.error import Error as Error
from influxdb_client.domain.expression import Expression as Expression
from influxdb_client.domain.expression_statement import ExpressionStatement as ExpressionStatement
from influxdb_client.domain.field import Field as Field
from influxdb_client.domain.file import File as File
from influxdb_client.domain.float_literal import FloatLiteral as FloatLiteral
from influxdb_client.domain.flux_response import FluxResponse as FluxResponse
from influxdb_client.domain.flux_suggestion import FluxSuggestion as FluxSuggestion
from influxdb_client.domain.flux_suggestions import FluxSuggestions as FluxSuggestions
from influxdb_client.domain.function_expression import FunctionExpression as FunctionExpression
from influxdb_client.domain.gauge_view_properties import GaugeViewProperties as GaugeViewProperties
from influxdb_client.domain.greater_threshold import GreaterThreshold as GreaterThreshold
from influxdb_client.domain.health_check import HealthCheck as HealthCheck
from influxdb_client.domain.heatmap_view_properties import HeatmapViewProperties as HeatmapViewProperties
from influxdb_client.domain.histogram_view_properties import HistogramViewProperties as HistogramViewProperties
from influxdb_client.domain.http_notification_endpoint import HTTPNotificationEndpoint as HTTPNotificationEndpoint
from influxdb_client.domain.http_notification_rule import HTTPNotificationRule as HTTPNotificationRule
from influxdb_client.domain.http_notification_rule_base import HTTPNotificationRuleBase as HTTPNotificationRuleBase
from influxdb_client.domain.identifier import Identifier as Identifier
from influxdb_client.domain.import_declaration import ImportDeclaration as ImportDeclaration
from influxdb_client.domain.index_expression import IndexExpression as IndexExpression
from influxdb_client.domain.integer_literal import IntegerLiteral as IntegerLiteral
from influxdb_client.domain.is_onboarding import IsOnboarding as IsOnboarding
from influxdb_client.domain.label import Label as Label
from influxdb_client.domain.label_create_request import LabelCreateRequest as LabelCreateRequest
from influxdb_client.domain.label_mapping import LabelMapping as LabelMapping
from influxdb_client.domain.label_response import LabelResponse as LabelResponse
from influxdb_client.domain.label_update import LabelUpdate as LabelUpdate
from influxdb_client.domain.labels_response import LabelsResponse as LabelsResponse
from influxdb_client.domain.language_request import LanguageRequest as LanguageRequest
from influxdb_client.domain.legacy_authorization_post_request import (
    LegacyAuthorizationPostRequest as LegacyAuthorizationPostRequest,
)
from influxdb_client.domain.lesser_threshold import LesserThreshold as LesserThreshold
from influxdb_client.domain.line_plus_single_stat_properties import LinePlusSingleStatProperties as LinePlusSingleStatProperties
from influxdb_client.domain.line_protocol_error import LineProtocolError as LineProtocolError
from influxdb_client.domain.line_protocol_length_error import LineProtocolLengthError as LineProtocolLengthError
from influxdb_client.domain.links import Links as Links
from influxdb_client.domain.list_stacks_response import ListStacksResponse as ListStacksResponse
from influxdb_client.domain.log_event import LogEvent as LogEvent
from influxdb_client.domain.logical_expression import LogicalExpression as LogicalExpression
from influxdb_client.domain.logs import Logs as Logs
from influxdb_client.domain.map_variable_properties import MapVariableProperties as MapVariableProperties
from influxdb_client.domain.markdown_view_properties import MarkdownViewProperties as MarkdownViewProperties
from influxdb_client.domain.measurement_schema import MeasurementSchema as MeasurementSchema
from influxdb_client.domain.measurement_schema_column import MeasurementSchemaColumn as MeasurementSchemaColumn
from influxdb_client.domain.measurement_schema_create_request import (
    MeasurementSchemaCreateRequest as MeasurementSchemaCreateRequest,
)
from influxdb_client.domain.measurement_schema_list import MeasurementSchemaList as MeasurementSchemaList
from influxdb_client.domain.measurement_schema_update_request import (
    MeasurementSchemaUpdateRequest as MeasurementSchemaUpdateRequest,
)
from influxdb_client.domain.member_assignment import MemberAssignment as MemberAssignment
from influxdb_client.domain.member_expression import MemberExpression as MemberExpression
from influxdb_client.domain.metadata_backup import MetadataBackup as MetadataBackup
from influxdb_client.domain.model_property import ModelProperty as ModelProperty
from influxdb_client.domain.mosaic_view_properties import MosaicViewProperties as MosaicViewProperties
from influxdb_client.domain.node import Node as Node
from influxdb_client.domain.notification_endpoint import NotificationEndpoint as NotificationEndpoint
from influxdb_client.domain.notification_endpoint_base import NotificationEndpointBase as NotificationEndpointBase
from influxdb_client.domain.notification_endpoint_base_links import NotificationEndpointBaseLinks as NotificationEndpointBaseLinks
from influxdb_client.domain.notification_endpoint_discriminator import (
    NotificationEndpointDiscriminator as NotificationEndpointDiscriminator,
)
from influxdb_client.domain.notification_endpoint_type import NotificationEndpointType as NotificationEndpointType
from influxdb_client.domain.notification_endpoint_update import NotificationEndpointUpdate as NotificationEndpointUpdate
from influxdb_client.domain.notification_endpoints import NotificationEndpoints as NotificationEndpoints
from influxdb_client.domain.notification_rule import NotificationRule as NotificationRule
from influxdb_client.domain.notification_rule_base import NotificationRuleBase as NotificationRuleBase
from influxdb_client.domain.notification_rule_base_links import NotificationRuleBaseLinks as NotificationRuleBaseLinks
from influxdb_client.domain.notification_rule_discriminator import NotificationRuleDiscriminator as NotificationRuleDiscriminator
from influxdb_client.domain.notification_rule_update import NotificationRuleUpdate as NotificationRuleUpdate
from influxdb_client.domain.notification_rules import NotificationRules as NotificationRules
from influxdb_client.domain.object_expression import ObjectExpression as ObjectExpression
from influxdb_client.domain.onboarding_request import OnboardingRequest as OnboardingRequest
from influxdb_client.domain.onboarding_response import OnboardingResponse as OnboardingResponse
from influxdb_client.domain.option_statement import OptionStatement as OptionStatement
from influxdb_client.domain.organization import Organization as Organization
from influxdb_client.domain.organization_links import OrganizationLinks as OrganizationLinks
from influxdb_client.domain.organizations import Organizations as Organizations
from influxdb_client.domain.package import Package as Package
from influxdb_client.domain.package_clause import PackageClause as PackageClause
from influxdb_client.domain.pager_duty_notification_endpoint import PagerDutyNotificationEndpoint as PagerDutyNotificationEndpoint
from influxdb_client.domain.pager_duty_notification_rule import PagerDutyNotificationRule as PagerDutyNotificationRule
from influxdb_client.domain.pager_duty_notification_rule_base import (
    PagerDutyNotificationRuleBase as PagerDutyNotificationRuleBase,
)
from influxdb_client.domain.paren_expression import ParenExpression as ParenExpression
from influxdb_client.domain.password_reset_body import PasswordResetBody as PasswordResetBody
from influxdb_client.domain.patch_bucket_request import PatchBucketRequest as PatchBucketRequest
from influxdb_client.domain.patch_dashboard_request import PatchDashboardRequest as PatchDashboardRequest
from influxdb_client.domain.patch_organization_request import PatchOrganizationRequest as PatchOrganizationRequest
from influxdb_client.domain.patch_retention_rule import PatchRetentionRule as PatchRetentionRule
from influxdb_client.domain.patch_stack_request import PatchStackRequest as PatchStackRequest
from influxdb_client.domain.patch_stack_request_additional_resources import (
    PatchStackRequestAdditionalResources as PatchStackRequestAdditionalResources,
)
from influxdb_client.domain.permission import Permission as Permission
from influxdb_client.domain.permission_resource import PermissionResource as PermissionResource
from influxdb_client.domain.pipe_expression import PipeExpression as PipeExpression
from influxdb_client.domain.pipe_literal import PipeLiteral as PipeLiteral
from influxdb_client.domain.post_bucket_request import PostBucketRequest as PostBucketRequest
from influxdb_client.domain.post_check import PostCheck as PostCheck
from influxdb_client.domain.post_notification_endpoint import PostNotificationEndpoint as PostNotificationEndpoint
from influxdb_client.domain.post_notification_rule import PostNotificationRule as PostNotificationRule
from influxdb_client.domain.post_organization_request import PostOrganizationRequest as PostOrganizationRequest
from influxdb_client.domain.post_restore_kv_response import PostRestoreKVResponse as PostRestoreKVResponse
from influxdb_client.domain.post_stack_request import PostStackRequest as PostStackRequest
from influxdb_client.domain.property_key import PropertyKey as PropertyKey
from influxdb_client.domain.query import Query as Query
from influxdb_client.domain.query_edit_mode import QueryEditMode as QueryEditMode
from influxdb_client.domain.query_variable_properties import QueryVariableProperties as QueryVariableProperties
from influxdb_client.domain.query_variable_properties_values import QueryVariablePropertiesValues as QueryVariablePropertiesValues
from influxdb_client.domain.range_threshold import RangeThreshold as RangeThreshold
from influxdb_client.domain.ready import Ready as Ready
from influxdb_client.domain.regexp_literal import RegexpLiteral as RegexpLiteral
from influxdb_client.domain.remote_connection import RemoteConnection as RemoteConnection
from influxdb_client.domain.remote_connection_creation_request import (
    RemoteConnectionCreationRequest as RemoteConnectionCreationRequest,
)
from influxdb_client.domain.remote_connection_update_request import RemoteConnectionUpdateRequest as RemoteConnectionUpdateRequest
from influxdb_client.domain.remote_connections import RemoteConnections as RemoteConnections
from influxdb_client.domain.renamable_field import RenamableField as RenamableField
from influxdb_client.domain.replication import Replication as Replication
from influxdb_client.domain.replication_creation_request import ReplicationCreationRequest as ReplicationCreationRequest
from influxdb_client.domain.replication_update_request import ReplicationUpdateRequest as ReplicationUpdateRequest
from influxdb_client.domain.replications import Replications as Replications
from influxdb_client.domain.resource_member import ResourceMember as ResourceMember
from influxdb_client.domain.resource_members import ResourceMembers as ResourceMembers
from influxdb_client.domain.resource_members_links import ResourceMembersLinks as ResourceMembersLinks
from influxdb_client.domain.resource_owner import ResourceOwner as ResourceOwner
from influxdb_client.domain.resource_owners import ResourceOwners as ResourceOwners
from influxdb_client.domain.restored_bucket_mappings import RestoredBucketMappings as RestoredBucketMappings
from influxdb_client.domain.retention_policy_manifest import RetentionPolicyManifest as RetentionPolicyManifest
from influxdb_client.domain.return_statement import ReturnStatement as ReturnStatement
from influxdb_client.domain.routes import Routes as Routes
from influxdb_client.domain.routes_external import RoutesExternal as RoutesExternal
from influxdb_client.domain.routes_query import RoutesQuery as RoutesQuery
from influxdb_client.domain.routes_system import RoutesSystem as RoutesSystem
from influxdb_client.domain.rule_status_level import RuleStatusLevel as RuleStatusLevel
from influxdb_client.domain.run import Run as Run
from influxdb_client.domain.run_links import RunLinks as RunLinks
from influxdb_client.domain.run_manually import RunManually as RunManually
from influxdb_client.domain.runs import Runs as Runs
from influxdb_client.domain.scatter_view_properties import ScatterViewProperties as ScatterViewProperties
from influxdb_client.domain.schema_type import SchemaType as SchemaType
from influxdb_client.domain.scraper_target_request import ScraperTargetRequest as ScraperTargetRequest
from influxdb_client.domain.scraper_target_response import ScraperTargetResponse as ScraperTargetResponse
from influxdb_client.domain.scraper_target_responses import ScraperTargetResponses as ScraperTargetResponses
from influxdb_client.domain.script import Script as Script
from influxdb_client.domain.script_create_request import ScriptCreateRequest as ScriptCreateRequest
from influxdb_client.domain.script_invocation_params import ScriptInvocationParams as ScriptInvocationParams
from influxdb_client.domain.script_language import ScriptLanguage as ScriptLanguage
from influxdb_client.domain.script_update_request import ScriptUpdateRequest as ScriptUpdateRequest
from influxdb_client.domain.scripts import Scripts as Scripts
from influxdb_client.domain.secret_keys import SecretKeys as SecretKeys
from influxdb_client.domain.secret_keys_response import SecretKeysResponse as SecretKeysResponse
from influxdb_client.domain.shard_group_manifest import ShardGroupManifest as ShardGroupManifest
from influxdb_client.domain.shard_manifest import ShardManifest as ShardManifest
from influxdb_client.domain.shard_owner import ShardOwner as ShardOwner
from influxdb_client.domain.simple_table_view_properties import SimpleTableViewProperties as SimpleTableViewProperties
from influxdb_client.domain.single_stat_view_properties import SingleStatViewProperties as SingleStatViewProperties
from influxdb_client.domain.slack_notification_endpoint import SlackNotificationEndpoint as SlackNotificationEndpoint
from influxdb_client.domain.slack_notification_rule import SlackNotificationRule as SlackNotificationRule
from influxdb_client.domain.slack_notification_rule_base import SlackNotificationRuleBase as SlackNotificationRuleBase
from influxdb_client.domain.smtp_notification_rule import SMTPNotificationRule as SMTPNotificationRule
from influxdb_client.domain.smtp_notification_rule_base import SMTPNotificationRuleBase as SMTPNotificationRuleBase
from influxdb_client.domain.source import Source as Source
from influxdb_client.domain.source_links import SourceLinks as SourceLinks
from influxdb_client.domain.sources import Sources as Sources
from influxdb_client.domain.stack import Stack as Stack
from influxdb_client.domain.stack_associations import StackAssociations as StackAssociations
from influxdb_client.domain.stack_events import StackEvents as StackEvents
from influxdb_client.domain.stack_links import StackLinks as StackLinks
from influxdb_client.domain.stack_resources import StackResources as StackResources
from influxdb_client.domain.statement import Statement as Statement
from influxdb_client.domain.static_legend import StaticLegend as StaticLegend
from influxdb_client.domain.status_rule import StatusRule as StatusRule
from influxdb_client.domain.string_literal import StringLiteral as StringLiteral
from influxdb_client.domain.subscription_manifest import SubscriptionManifest as SubscriptionManifest
from influxdb_client.domain.table_view_properties import TableViewProperties as TableViewProperties
from influxdb_client.domain.table_view_properties_table_options import (
    TableViewPropertiesTableOptions as TableViewPropertiesTableOptions,
)
from influxdb_client.domain.tag_rule import TagRule as TagRule
from influxdb_client.domain.task import Task as Task
from influxdb_client.domain.task_create_request import TaskCreateRequest as TaskCreateRequest
from influxdb_client.domain.task_links import TaskLinks as TaskLinks
from influxdb_client.domain.task_status_type import TaskStatusType as TaskStatusType
from influxdb_client.domain.task_update_request import TaskUpdateRequest as TaskUpdateRequest
from influxdb_client.domain.tasks import Tasks as Tasks
from influxdb_client.domain.telegraf import Telegraf as Telegraf
from influxdb_client.domain.telegraf_plugin import TelegrafPlugin as TelegrafPlugin
from influxdb_client.domain.telegraf_plugin_request import TelegrafPluginRequest as TelegrafPluginRequest
from influxdb_client.domain.telegraf_plugin_request_plugins import TelegrafPluginRequestPlugins as TelegrafPluginRequestPlugins
from influxdb_client.domain.telegraf_plugins import TelegrafPlugins as TelegrafPlugins
from influxdb_client.domain.telegraf_request import TelegrafRequest as TelegrafRequest
from influxdb_client.domain.telegraf_request_metadata import TelegrafRequestMetadata as TelegrafRequestMetadata
from influxdb_client.domain.telegrafs import Telegrafs as Telegrafs
from influxdb_client.domain.telegram_notification_endpoint import TelegramNotificationEndpoint as TelegramNotificationEndpoint
from influxdb_client.domain.telegram_notification_rule import TelegramNotificationRule as TelegramNotificationRule
from influxdb_client.domain.telegram_notification_rule_base import TelegramNotificationRuleBase as TelegramNotificationRuleBase
from influxdb_client.domain.template_apply import TemplateApply as TemplateApply
from influxdb_client.domain.template_apply_remotes import TemplateApplyRemotes as TemplateApplyRemotes
from influxdb_client.domain.template_apply_template import TemplateApplyTemplate as TemplateApplyTemplate
from influxdb_client.domain.template_chart import TemplateChart as TemplateChart
from influxdb_client.domain.template_export_by_id import TemplateExportByID as TemplateExportByID
from influxdb_client.domain.template_export_by_id_org_ids import TemplateExportByIDOrgIDs as TemplateExportByIDOrgIDs
from influxdb_client.domain.template_export_by_id_resource_filters import (
    TemplateExportByIDResourceFilters as TemplateExportByIDResourceFilters,
)
from influxdb_client.domain.template_export_by_id_resources import TemplateExportByIDResources as TemplateExportByIDResources
from influxdb_client.domain.template_kind import TemplateKind as TemplateKind
from influxdb_client.domain.template_summary import TemplateSummary as TemplateSummary
from influxdb_client.domain.template_summary_diff import TemplateSummaryDiff as TemplateSummaryDiff
from influxdb_client.domain.template_summary_diff_buckets import TemplateSummaryDiffBuckets as TemplateSummaryDiffBuckets
from influxdb_client.domain.template_summary_diff_buckets_new_old import (
    TemplateSummaryDiffBucketsNewOld as TemplateSummaryDiffBucketsNewOld,
)
from influxdb_client.domain.template_summary_diff_checks import TemplateSummaryDiffChecks as TemplateSummaryDiffChecks
from influxdb_client.domain.template_summary_diff_dashboards import TemplateSummaryDiffDashboards as TemplateSummaryDiffDashboards
from influxdb_client.domain.template_summary_diff_dashboards_new_old import (
    TemplateSummaryDiffDashboardsNewOld as TemplateSummaryDiffDashboardsNewOld,
)
from influxdb_client.domain.template_summary_diff_label_mappings import (
    TemplateSummaryDiffLabelMappings as TemplateSummaryDiffLabelMappings,
)
from influxdb_client.domain.template_summary_diff_labels import TemplateSummaryDiffLabels as TemplateSummaryDiffLabels
from influxdb_client.domain.template_summary_diff_labels_new_old import (
    TemplateSummaryDiffLabelsNewOld as TemplateSummaryDiffLabelsNewOld,
)
from influxdb_client.domain.template_summary_diff_notification_endpoints import (
    TemplateSummaryDiffNotificationEndpoints as TemplateSummaryDiffNotificationEndpoints,
)
from influxdb_client.domain.template_summary_diff_notification_rules import (
    TemplateSummaryDiffNotificationRules as TemplateSummaryDiffNotificationRules,
)
from influxdb_client.domain.template_summary_diff_notification_rules_new_old import (
    TemplateSummaryDiffNotificationRulesNewOld as TemplateSummaryDiffNotificationRulesNewOld,
)
from influxdb_client.domain.template_summary_diff_tasks import TemplateSummaryDiffTasks as TemplateSummaryDiffTasks
from influxdb_client.domain.template_summary_diff_tasks_new_old import (
    TemplateSummaryDiffTasksNewOld as TemplateSummaryDiffTasksNewOld,
)
from influxdb_client.domain.template_summary_diff_telegraf_configs import (
    TemplateSummaryDiffTelegrafConfigs as TemplateSummaryDiffTelegrafConfigs,
)
from influxdb_client.domain.template_summary_diff_variables import TemplateSummaryDiffVariables as TemplateSummaryDiffVariables
from influxdb_client.domain.template_summary_diff_variables_new_old import (
    TemplateSummaryDiffVariablesNewOld as TemplateSummaryDiffVariablesNewOld,
)
from influxdb_client.domain.template_summary_errors import TemplateSummaryErrors as TemplateSummaryErrors
from influxdb_client.domain.template_summary_label import TemplateSummaryLabel as TemplateSummaryLabel
from influxdb_client.domain.template_summary_label_properties import (
    TemplateSummaryLabelProperties as TemplateSummaryLabelProperties,
)
from influxdb_client.domain.template_summary_summary import TemplateSummarySummary as TemplateSummarySummary
from influxdb_client.domain.template_summary_summary_buckets import TemplateSummarySummaryBuckets as TemplateSummarySummaryBuckets
from influxdb_client.domain.template_summary_summary_dashboards import (
    TemplateSummarySummaryDashboards as TemplateSummarySummaryDashboards,
)
from influxdb_client.domain.template_summary_summary_label_mappings import (
    TemplateSummarySummaryLabelMappings as TemplateSummarySummaryLabelMappings,
)
from influxdb_client.domain.template_summary_summary_notification_rules import (
    TemplateSummarySummaryNotificationRules as TemplateSummarySummaryNotificationRules,
)
from influxdb_client.domain.template_summary_summary_status_rules import (
    TemplateSummarySummaryStatusRules as TemplateSummarySummaryStatusRules,
)
from influxdb_client.domain.template_summary_summary_tag_rules import (
    TemplateSummarySummaryTagRules as TemplateSummarySummaryTagRules,
)
from influxdb_client.domain.template_summary_summary_tasks import TemplateSummarySummaryTasks as TemplateSummarySummaryTasks
from influxdb_client.domain.template_summary_summary_variables import (
    TemplateSummarySummaryVariables as TemplateSummarySummaryVariables,
)
from influxdb_client.domain.test_statement import TestStatement as TestStatement
from influxdb_client.domain.threshold import Threshold as Threshold
from influxdb_client.domain.threshold_base import ThresholdBase as ThresholdBase
from influxdb_client.domain.threshold_check import ThresholdCheck as ThresholdCheck
from influxdb_client.domain.unary_expression import UnaryExpression as UnaryExpression
from influxdb_client.domain.unsigned_integer_literal import UnsignedIntegerLiteral as UnsignedIntegerLiteral
from influxdb_client.domain.user import User as User
from influxdb_client.domain.user_response import UserResponse as UserResponse
from influxdb_client.domain.user_response_links import UserResponseLinks as UserResponseLinks
from influxdb_client.domain.users import Users as Users
from influxdb_client.domain.variable import Variable as Variable
from influxdb_client.domain.variable_assignment import VariableAssignment as VariableAssignment
from influxdb_client.domain.variable_links import VariableLinks as VariableLinks
from influxdb_client.domain.variable_properties import VariableProperties as VariableProperties
from influxdb_client.domain.variables import Variables as Variables
from influxdb_client.domain.view import View as View
from influxdb_client.domain.view_links import ViewLinks as ViewLinks
from influxdb_client.domain.view_properties import ViewProperties as ViewProperties
from influxdb_client.domain.views import Views as Views
from influxdb_client.domain.write_precision import WritePrecision as WritePrecision
from influxdb_client.domain.xy_geom import XYGeom as XYGeom
from influxdb_client.domain.xy_view_properties import XYViewProperties as XYViewProperties
from influxdb_client.service.authorizations_service import AuthorizationsService as AuthorizationsService
from influxdb_client.service.backup_service import BackupService as BackupService
from influxdb_client.service.bucket_schemas_service import BucketSchemasService as BucketSchemasService
from influxdb_client.service.buckets_service import BucketsService as BucketsService
from influxdb_client.service.cells_service import CellsService as CellsService
from influxdb_client.service.checks_service import ChecksService as ChecksService
from influxdb_client.service.config_service import ConfigService as ConfigService
from influxdb_client.service.dashboards_service import DashboardsService as DashboardsService
from influxdb_client.service.dbr_ps_service import DBRPsService as DBRPsService
from influxdb_client.service.delete_service import DeleteService as DeleteService
from influxdb_client.service.health_service import HealthService as HealthService
from influxdb_client.service.invokable_scripts_service import InvokableScriptsService as InvokableScriptsService
from influxdb_client.service.labels_service import LabelsService as LabelsService
from influxdb_client.service.legacy_authorizations_service import LegacyAuthorizationsService as LegacyAuthorizationsService
from influxdb_client.service.metrics_service import MetricsService as MetricsService
from influxdb_client.service.notification_endpoints_service import NotificationEndpointsService as NotificationEndpointsService
from influxdb_client.service.notification_rules_service import NotificationRulesService as NotificationRulesService
from influxdb_client.service.organizations_service import OrganizationsService as OrganizationsService
from influxdb_client.service.ping_service import PingService as PingService
from influxdb_client.service.query_service import QueryService as QueryService
from influxdb_client.service.ready_service import ReadyService as ReadyService
from influxdb_client.service.remote_connections_service import RemoteConnectionsService as RemoteConnectionsService
from influxdb_client.service.replications_service import ReplicationsService as ReplicationsService
from influxdb_client.service.resources_service import ResourcesService as ResourcesService
from influxdb_client.service.restore_service import RestoreService as RestoreService
from influxdb_client.service.routes_service import RoutesService as RoutesService
from influxdb_client.service.rules_service import RulesService as RulesService
from influxdb_client.service.scraper_targets_service import ScraperTargetsService as ScraperTargetsService
from influxdb_client.service.secrets_service import SecretsService as SecretsService
from influxdb_client.service.setup_service import SetupService as SetupService
from influxdb_client.service.signin_service import SigninService as SigninService
from influxdb_client.service.signout_service import SignoutService as SignoutService
from influxdb_client.service.sources_service import SourcesService as SourcesService
from influxdb_client.service.tasks_service import TasksService as TasksService
from influxdb_client.service.telegraf_plugins_service import TelegrafPluginsService as TelegrafPluginsService
from influxdb_client.service.telegrafs_service import TelegrafsService as TelegrafsService
from influxdb_client.service.templates_service import TemplatesService as TemplatesService
from influxdb_client.service.users_service import UsersService as UsersService
from influxdb_client.service.variables_service import VariablesService as VariablesService
from influxdb_client.service.views_service import ViewsService as ViewsService
from influxdb_client.service.write_service import WriteService as WriteService
from influxdb_client.version import VERSION as VERSION

__version__ = VERSION



from _typeshed import Incomplete

class _BaseService:
    api_client: Incomplete
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def build_type(self) -> str: ...
    async def build_type_async(self) -> str: ...
    def response_header(self, response, header_name: str = "X-Influxdb-Version") -> str: ...



from _typeshed import Incomplete

class Node:
    openapi_types: Incomplete
    attribute_map: Incomplete
    def __init__(self) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class StackEvents:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        event_type: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        sources: Incomplete | None = None,
        resources: Incomplete | None = None,
        urls: Incomplete | None = None,
        updated_at: Incomplete | None = None,
    ) -> None: ...
    @property
    def event_type(self): ...
    @event_type.setter
    def event_type(self, event_type) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def sources(self): ...
    @sources.setter
    def sources(self, sources) -> None: ...
    @property
    def resources(self): ...
    @resources.setter
    def resources(self, resources) -> None: ...
    @property
    def urls(self): ...
    @urls.setter
    def urls(self, urls) -> None: ...
    @property
    def updated_at(self): ...
    @updated_at.setter
    def updated_at(self, updated_at) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



import logging
from _typeshed import Incomplete

class InfluxLoggingHandler(logging.Handler):
    DEFAULT_LOG_RECORD_KEYS: Incomplete
    bucket: Incomplete
    client: Incomplete
    write_api: Incomplete
    def __init__(
        self, *, url, token, org, bucket, client_args: Incomplete | None = None, write_api_args: Incomplete | None = None
    ) -> None: ...
    def __del__(self) -> None: ...
    def close(self) -> None: ...
    def emit(self, record: logging.LogRecord) -> None: ...



from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class BandViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        adaptive_zoom_hide: bool | None = None,
        time_format: Incomplete | None = None,
        type: Incomplete | None = None,
        queries: Incomplete | None = None,
        colors: Incomplete | None = None,
        shape: Incomplete | None = None,
        note: Incomplete | None = None,
        show_note_when_empty: Incomplete | None = None,
        axes: Incomplete | None = None,
        static_legend: Incomplete | None = None,
        x_column: Incomplete | None = None,
        generate_x_axis_ticks: Incomplete | None = None,
        x_total_ticks: Incomplete | None = None,
        x_tick_start: Incomplete | None = None,
        x_tick_step: Incomplete | None = None,
        y_column: Incomplete | None = None,
        generate_y_axis_ticks: Incomplete | None = None,
        y_total_ticks: Incomplete | None = None,
        y_tick_start: Incomplete | None = None,
        y_tick_step: Incomplete | None = None,
        upper_column: Incomplete | None = None,
        main_column: Incomplete | None = None,
        lower_column: Incomplete | None = None,
        hover_dimension: Incomplete | None = None,
        geom: Incomplete | None = None,
        legend_colorize_rows: Incomplete | None = None,
        legend_hide: Incomplete | None = None,
        legend_opacity: Incomplete | None = None,
        legend_orientation_threshold: Incomplete | None = None,
    ) -> None: ...
    adaptive_zoom_hide: bool | None
    @property
    def time_format(self): ...
    @time_format.setter
    def time_format(self, time_format) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def queries(self): ...
    @queries.setter
    def queries(self, queries) -> None: ...
    @property
    def colors(self): ...
    @colors.setter
    def colors(self, colors) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def note(self): ...
    @note.setter
    def note(self, note) -> None: ...
    @property
    def show_note_when_empty(self): ...
    @show_note_when_empty.setter
    def show_note_when_empty(self, show_note_when_empty) -> None: ...
    @property
    def axes(self): ...
    @axes.setter
    def axes(self, axes) -> None: ...
    @property
    def static_legend(self): ...
    @static_legend.setter
    def static_legend(self, static_legend) -> None: ...
    @property
    def x_column(self): ...
    @x_column.setter
    def x_column(self, x_column) -> None: ...
    @property
    def generate_x_axis_ticks(self): ...
    @generate_x_axis_ticks.setter
    def generate_x_axis_ticks(self, generate_x_axis_ticks) -> None: ...
    @property
    def x_total_ticks(self): ...
    @x_total_ticks.setter
    def x_total_ticks(self, x_total_ticks) -> None: ...
    @property
    def x_tick_start(self): ...
    @x_tick_start.setter
    def x_tick_start(self, x_tick_start) -> None: ...
    @property
    def x_tick_step(self): ...
    @x_tick_step.setter
    def x_tick_step(self, x_tick_step) -> None: ...
    @property
    def y_column(self): ...
    @y_column.setter
    def y_column(self, y_column) -> None: ...
    @property
    def generate_y_axis_ticks(self): ...
    @generate_y_axis_ticks.setter
    def generate_y_axis_ticks(self, generate_y_axis_ticks) -> None: ...
    @property
    def y_total_ticks(self): ...
    @y_total_ticks.setter
    def y_total_ticks(self, y_total_ticks) -> None: ...
    @property
    def y_tick_start(self): ...
    @y_tick_start.setter
    def y_tick_start(self, y_tick_start) -> None: ...
    @property
    def y_tick_step(self): ...
    @y_tick_step.setter
    def y_tick_step(self, y_tick_step) -> None: ...
    @property
    def upper_column(self): ...
    @upper_column.setter
    def upper_column(self, upper_column) -> None: ...
    @property
    def main_column(self): ...
    @main_column.setter
    def main_column(self, main_column) -> None: ...
    @property
    def lower_column(self): ...
    @lower_column.setter
    def lower_column(self, lower_column) -> None: ...
    @property
    def hover_dimension(self): ...
    @hover_dimension.setter
    def hover_dimension(self, hover_dimension) -> None: ...
    @property
    def geom(self): ...
    @geom.setter
    def geom(self, geom) -> None: ...
    @property
    def legend_colorize_rows(self): ...
    @legend_colorize_rows.setter
    def legend_colorize_rows(self, legend_colorize_rows) -> None: ...
    @property
    def legend_hide(self): ...
    @legend_hide.setter
    def legend_hide(self, legend_hide) -> None: ...
    @property
    def legend_opacity(self): ...
    @legend_opacity.setter
    def legend_opacity(self, legend_opacity) -> None: ...
    @property
    def legend_orientation_threshold(self): ...
    @legend_orientation_threshold.setter
    def legend_orientation_threshold(self, legend_orientation_threshold) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class VariablesService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_variables_id(self, variable_id, **kwargs): ...
    def delete_variables_id_with_http_info(self, variable_id, **kwargs): ...
    async def delete_variables_id_async(self, variable_id, **kwargs): ...
    def delete_variables_id_labels_id(self, variable_id, label_id, **kwargs): ...
    def delete_variables_id_labels_id_with_http_info(self, variable_id, label_id, **kwargs): ...
    async def delete_variables_id_labels_id_async(self, variable_id, label_id, **kwargs): ...
    def get_variables(self, **kwargs): ...
    def get_variables_with_http_info(self, **kwargs): ...
    async def get_variables_async(self, **kwargs): ...
    def get_variables_id(self, variable_id, **kwargs): ...
    def get_variables_id_with_http_info(self, variable_id, **kwargs): ...
    async def get_variables_id_async(self, variable_id, **kwargs): ...
    def get_variables_id_labels(self, variable_id, **kwargs): ...
    def get_variables_id_labels_with_http_info(self, variable_id, **kwargs): ...
    async def get_variables_id_labels_async(self, variable_id, **kwargs): ...
    def patch_variables_id(self, variable_id, variable, **kwargs): ...
    def patch_variables_id_with_http_info(self, variable_id, variable, **kwargs): ...
    async def patch_variables_id_async(self, variable_id, variable, **kwargs): ...
    def post_variables(self, variable, **kwargs): ...
    def post_variables_with_http_info(self, variable, **kwargs): ...
    async def post_variables_async(self, variable, **kwargs): ...
    def post_variables_id_labels(self, variable_id, label_mapping, **kwargs): ...
    def post_variables_id_labels_with_http_info(self, variable_id, label_mapping, **kwargs): ...
    async def post_variables_id_labels_async(self, variable_id, label_mapping, **kwargs): ...
    def put_variables_id(self, variable_id, variable, **kwargs): ...
    def put_variables_id_with_http_info(self, variable_id, variable, **kwargs): ...
    async def put_variables_id_async(self, variable_id, variable, **kwargs): ...



from _typeshed import Incomplete

class VariableLinks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, _self: Incomplete | None = None, org: Incomplete | None = None, labels: Incomplete | None = None
    ) -> None: ...
    @property
    def org(self): ...
    @org.setter
    def org(self, org) -> None: ...
    @property
    def labels(self): ...
    @labels.setter
    def labels(self, labels) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class MetadataBackup:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, kv: Incomplete | None = None, sql: Incomplete | None = None, buckets: Incomplete | None = None
    ) -> None: ...
    @property
    def kv(self): ...
    @kv.setter
    def kv(self, kv) -> None: ...
    @property
    def sql(self): ...
    @sql.setter
    def sql(self, sql) -> None: ...
    @property
    def buckets(self): ...
    @buckets.setter
    def buckets(self, buckets) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class RenamableField:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, internal_name: Incomplete | None = None, display_name: Incomplete | None = None, visible: Incomplete | None = None
    ) -> None: ...
    @property
    def internal_name(self): ...
    @internal_name.setter
    def internal_name(self, internal_name) -> None: ...
    @property
    def display_name(self): ...
    @display_name.setter
    def display_name(self, display_name) -> None: ...
    @property
    def visible(self): ...
    @visible.setter
    def visible(self, visible) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class RunLinks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, _self: Incomplete | None = None, task: Incomplete | None = None, retry: Incomplete | None = None
    ) -> None: ...
    @property
    def task(self): ...
    @task.setter
    def task(self, task) -> None: ...
    @property
    def retry(self): ...
    @retry.setter
    def retry(self, retry) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class LineProtocolLengthError:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, code: Incomplete | None = None, message: Incomplete | None = None) -> None: ...
    @property
    def code(self): ...
    @code.setter
    def code(self, code) -> None: ...
    @property
    def message(self): ...
    @message.setter
    def message(self, message) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.domain.create_dashboard_request import CreateDashboardRequest

class DashboardWithViewProperties(CreateDashboardRequest):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        links: Incomplete | None = None,
        id: Incomplete | None = None,
        meta: Incomplete | None = None,
        cells: Incomplete | None = None,
        labels: Incomplete | None = None,
        org_id: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
    ) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def meta(self): ...
    @meta.setter
    def meta(self, meta) -> None: ...
    @property
    def cells(self): ...
    @cells.setter
    def cells(self, cells) -> None: ...
    @property
    def labels(self): ...
    @labels.setter
    def labels(self, labels) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class RemoteConnectionsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_remote_connection_by_id(self, remote_id, **kwargs): ...
    def delete_remote_connection_by_id_with_http_info(self, remote_id, **kwargs): ...
    async def delete_remote_connection_by_id_async(self, remote_id, **kwargs): ...
    def get_remote_connection_by_id(self, remote_id, **kwargs): ...
    def get_remote_connection_by_id_with_http_info(self, remote_id, **kwargs): ...
    async def get_remote_connection_by_id_async(self, remote_id, **kwargs): ...
    def get_remote_connections(self, org_id, **kwargs): ...
    def get_remote_connections_with_http_info(self, org_id, **kwargs): ...
    async def get_remote_connections_async(self, org_id, **kwargs): ...
    def patch_remote_connection_by_id(self, remote_id, remote_connection_update_request, **kwargs): ...
    def patch_remote_connection_by_id_with_http_info(self, remote_id, remote_connection_update_request, **kwargs): ...
    async def patch_remote_connection_by_id_async(self, remote_id, remote_connection_update_request, **kwargs): ...
    def post_remote_connection(self, remote_connection_creation_request, **kwargs): ...
    def post_remote_connection_with_http_info(self, remote_connection_creation_request, **kwargs): ...
    async def post_remote_connection_async(self, remote_connection_creation_request, **kwargs): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class LabelsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_labels_id(self, label_id, **kwargs): ...
    def delete_labels_id_with_http_info(self, label_id, **kwargs): ...
    async def delete_labels_id_async(self, label_id, **kwargs): ...
    def get_labels(self, **kwargs): ...
    def get_labels_with_http_info(self, **kwargs): ...
    async def get_labels_async(self, **kwargs): ...
    def get_labels_id(self, label_id, **kwargs): ...
    def get_labels_id_with_http_info(self, label_id, **kwargs): ...
    async def get_labels_id_async(self, label_id, **kwargs): ...
    def patch_labels_id(self, label_id, label_update, **kwargs): ...
    def patch_labels_id_with_http_info(self, label_id, label_update, **kwargs): ...
    async def patch_labels_id_async(self, label_id, label_update, **kwargs): ...
    def post_labels(self, label_create_request, **kwargs): ...
    def post_labels_with_http_info(self, label_create_request, **kwargs): ...
    async def post_labels_async(self, label_create_request, **kwargs): ...



from _typeshed import Incomplete

class ShardGroupManifest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        id: Incomplete | None = None,
        start_time: Incomplete | None = None,
        end_time: Incomplete | None = None,
        deleted_at: Incomplete | None = None,
        truncated_at: Incomplete | None = None,
        shards: Incomplete | None = None,
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def start_time(self): ...
    @start_time.setter
    def start_time(self, start_time) -> None: ...
    @property
    def end_time(self): ...
    @end_time.setter
    def end_time(self, end_time) -> None: ...
    @property
    def deleted_at(self): ...
    @deleted_at.setter
    def deleted_at(self, deleted_at) -> None: ...
    @property
    def truncated_at(self): ...
    @truncated_at.setter
    def truncated_at(self, truncated_at) -> None: ...
    @property
    def shards(self): ...
    @shards.setter
    def shards(self, shards) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TableViewPropertiesTableOptions:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        vertical_time_axis: Incomplete | None = None,
        sort_by: Incomplete | None = None,
        wrapping: Incomplete | None = None,
        fix_first_column: Incomplete | None = None,
    ) -> None: ...
    @property
    def vertical_time_axis(self): ...
    @vertical_time_axis.setter
    def vertical_time_axis(self, vertical_time_axis) -> None: ...
    @property
    def sort_by(self): ...
    @sort_by.setter
    def sort_by(self, sort_by) -> None: ...
    @property
    def wrapping(self): ...
    @wrapping.setter
    def wrapping(self, wrapping) -> None: ...
    @property
    def fix_first_column(self): ...
    @fix_first_column.setter
    def fix_first_column(self, fix_first_column) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class CheckBase:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        id: Incomplete | None = None,
        name: Incomplete | None = None,
        org_id: Incomplete | None = None,
        task_id: Incomplete | None = None,
        owner_id: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        query: Incomplete | None = None,
        status: Incomplete | None = None,
        description: Incomplete | None = None,
        latest_completed: Incomplete | None = None,
        last_run_status: Incomplete | None = None,
        last_run_error: Incomplete | None = None,
        labels: Incomplete | None = None,
        links: Incomplete | None = None,
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def task_id(self): ...
    @task_id.setter
    def task_id(self, task_id) -> None: ...
    @property
    def owner_id(self): ...
    @owner_id.setter
    def owner_id(self, owner_id) -> None: ...
    @property
    def created_at(self): ...
    @created_at.setter
    def created_at(self, created_at) -> None: ...
    @property
    def updated_at(self): ...
    @updated_at.setter
    def updated_at(self, updated_at) -> None: ...
    @property
    def query(self): ...
    @query.setter
    def query(self, query) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def latest_completed(self): ...
    @latest_completed.setter
    def latest_completed(self, latest_completed) -> None: ...
    @property
    def last_run_status(self): ...
    @last_run_status.setter
    def last_run_status(self, last_run_status) -> None: ...
    @property
    def last_run_error(self): ...
    @last_run_error.setter
    def last_run_error(self, last_run_error) -> None: ...
    @property
    def labels(self): ...
    @labels.setter
    def labels(self, labels) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class TelegrafsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_telegrafs_id(self, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_with_http_info(self, telegraf_id, **kwargs): ...
    async def delete_telegrafs_id_async(self, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_labels_id(self, telegraf_id, label_id, **kwargs): ...
    def delete_telegrafs_id_labels_id_with_http_info(self, telegraf_id, label_id, **kwargs): ...
    async def delete_telegrafs_id_labels_id_async(self, telegraf_id, label_id, **kwargs): ...
    def delete_telegrafs_id_members_id(self, user_id, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_members_id_with_http_info(self, user_id, telegraf_id, **kwargs): ...
    async def delete_telegrafs_id_members_id_async(self, user_id, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_owners_id(self, user_id, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_owners_id_with_http_info(self, user_id, telegraf_id, **kwargs): ...
    async def delete_telegrafs_id_owners_id_async(self, user_id, telegraf_id, **kwargs): ...
    def get_telegrafs(self, **kwargs): ...
    def get_telegrafs_with_http_info(self, **kwargs): ...
    async def get_telegrafs_async(self, **kwargs): ...
    def get_telegrafs_id(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_async(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_labels(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_labels_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_labels_async(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_members(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_members_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_members_async(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_owners(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_owners_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_owners_async(self, telegraf_id, **kwargs): ...
    def post_telegrafs(self, telegraf_plugin_request, **kwargs): ...
    def post_telegrafs_with_http_info(self, telegraf_plugin_request, **kwargs): ...
    async def post_telegrafs_async(self, telegraf_plugin_request, **kwargs): ...
    def post_telegrafs_id_labels(self, telegraf_id, label_mapping, **kwargs): ...
    def post_telegrafs_id_labels_with_http_info(self, telegraf_id, label_mapping, **kwargs): ...
    async def post_telegrafs_id_labels_async(self, telegraf_id, label_mapping, **kwargs): ...
    def post_telegrafs_id_members(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def post_telegrafs_id_members_with_http_info(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    async def post_telegrafs_id_members_async(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def post_telegrafs_id_owners(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def post_telegrafs_id_owners_with_http_info(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    async def post_telegrafs_id_owners_async(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def put_telegrafs_id(self, telegraf_id, telegraf_plugin_request, **kwargs): ...
    def put_telegrafs_id_with_http_info(self, telegraf_id, telegraf_plugin_request, **kwargs): ...
    async def put_telegrafs_id_async(self, telegraf_id, telegraf_plugin_request, **kwargs): ...



from _typeshed import Incomplete

from influxdb_client import Authorization, Organization, User

class AuthorizationsApi:
    def __init__(self, influxdb_client) -> None: ...
    def create_authorization(
        self,
        org_id: Incomplete | None = None,
        permissions: list[Incomplete] | None = None,
        authorization: Authorization | None = None,
    ) -> Authorization: ...
    def find_authorization_by_id(self, auth_id: str) -> Authorization: ...
    def find_authorizations(self, **kwargs): ...
    def find_authorizations_by_user(self, user: User): ...
    def find_authorizations_by_user_id(self, user_id: str): ...
    def find_authorizations_by_user_name(self, user_name: str): ...
    def find_authorizations_by_org(self, org: Organization): ...
    def find_authorizations_by_org_name(self, org_name: str): ...
    def find_authorizations_by_org_id(self, org_id: str): ...
    def update_authorization(self, auth): ...
    def clone_authorization(self, auth) -> Authorization: ...
    def delete_authorization(self, auth): ...



from _typeshed import Incomplete

class Duration:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, type: Incomplete | None = None, magnitude: Incomplete | None = None, unit: Incomplete | None = None
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def magnitude(self): ...
    @magnitude.setter
    def magnitude(self, magnitude) -> None: ...
    @property
    def unit(self): ...
    @unit.setter
    def unit(self, unit) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class ScriptCreateRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        script: Incomplete | None = None,
        language: Incomplete | None = None,
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def script(self): ...
    @script.setter
    def script(self, script) -> None: ...
    @property
    def language(self): ...
    @language.setter
    def language(self, language) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class MeasurementSchemaColumn:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, name: Incomplete | None = None, type: Incomplete | None = None, data_type: Incomplete | None = None
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def data_type(self): ...
    @data_type.setter
    def data_type(self, data_type) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class SecretsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_orgs_id_secrets_id(self, org_id, secret_id, **kwargs): ...
    def delete_orgs_id_secrets_id_with_http_info(self, org_id, secret_id, **kwargs): ...
    async def delete_orgs_id_secrets_id_async(self, org_id, secret_id, **kwargs): ...
    def get_orgs_id_secrets(self, org_id, **kwargs): ...
    def get_orgs_id_secrets_with_http_info(self, org_id, **kwargs): ...
    async def get_orgs_id_secrets_async(self, org_id, **kwargs): ...
    def patch_orgs_id_secrets(self, org_id, request_body, **kwargs): ...
    def patch_orgs_id_secrets_with_http_info(self, org_id, request_body, **kwargs): ...
    async def patch_orgs_id_secrets_async(self, org_id, request_body, **kwargs): ...
    def post_orgs_id_secrets(self, org_id, secret_keys, **kwargs): ...
    def post_orgs_id_secrets_with_http_info(self, org_id, secret_keys, **kwargs): ...
    async def post_orgs_id_secrets_async(self, org_id, secret_keys, **kwargs): ...



from _typeshed import Incomplete, SupportsGetItem, SupportsItems
from collections.abc import Iterable
from datetime import datetime, timedelta
from numbers import Integral
from typing import Any
from typing_extensions import Literal, Self, TypeAlias

from influxdb_client.domain.write_precision import _WritePrecision

_Value: TypeAlias = Incomplete
_Time: TypeAlias = Integral | str | datetime | timedelta

EPOCH: datetime
DEFAULT_WRITE_PRECISION: _WritePrecision

class Point:
    @staticmethod
    def measurement(measurement: str) -> Point: ...
    @staticmethod
    def from_dict(
        dictionary: SupportsGetItem[str, Any],
        write_precision: _WritePrecision = "ns",
        *,
        record_measurement_name: str | None = ...,
        record_measurement_key: str = ...,
        record_tag_keys: Iterable[str] | None = ...,
        record_field_keys: Iterable[str] | None = ...,
        record_time_key: str = ...,
        fields: SupportsItems[str, Literal["int", "uint", "float"]] = ...,
    ) -> Point: ...
    def __init__(self, measurement_name: str) -> None: ...
    def time(self, time: _Time, write_precision: _WritePrecision = "ns") -> Self: ...
    def tag(self, key: str, value: _Value) -> Self: ...
    def field(self, field: str, value: _Value) -> Self: ...
    def to_line_protocol(self, precision: _WritePrecision | None = None) -> str: ...
    @property
    def write_precision(self) -> _WritePrecision: ...
    @classmethod
    def set_str_rep(cls, rep_function: Any) -> None: ...



from _typeshed import Incomplete

class ShardManifest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, id: Incomplete | None = None, shard_owners: Incomplete | None = None) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def shard_owners(self): ...
    @shard_owners.setter
    def shard_owners(self, shard_owners) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class CreateCell:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        name: Incomplete | None = None,
        x: Incomplete | None = None,
        y: Incomplete | None = None,
        w: Incomplete | None = None,
        h: Incomplete | None = None,
        using_view: Incomplete | None = None,
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def x(self): ...
    @x.setter
    def x(self, x) -> None: ...
    @property
    def y(self): ...
    @y.setter
    def y(self, y) -> None: ...
    @property
    def w(self): ...
    @w.setter
    def w(self, w) -> None: ...
    @property
    def h(self): ...
    @h.setter
    def h(self, h) -> None: ...
    @property
    def using_view(self): ...
    @using_view.setter
    def using_view(self, using_view) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class HistogramViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        queries: Incomplete | None = None,
        colors: Incomplete | None = None,
        shape: Incomplete | None = None,
        note: Incomplete | None = None,
        show_note_when_empty: Incomplete | None = None,
        x_column: Incomplete | None = None,
        fill_columns: Incomplete | None = None,
        x_domain: Incomplete | None = None,
        x_axis_label: Incomplete | None = None,
        position: Incomplete | None = None,
        bin_count: Incomplete | None = None,
        legend_colorize_rows: Incomplete | None = None,
        legend_hide: Incomplete | None = None,
        legend_opacity: Incomplete | None = None,
        legend_orientation_threshold: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def queries(self): ...
    @queries.setter
    def queries(self, queries) -> None: ...
    @property
    def colors(self): ...
    @colors.setter
    def colors(self, colors) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def note(self): ...
    @note.setter
    def note(self, note) -> None: ...
    @property
    def show_note_when_empty(self): ...
    @show_note_when_empty.setter
    def show_note_when_empty(self, show_note_when_empty) -> None: ...
    @property
    def x_column(self): ...
    @x_column.setter
    def x_column(self, x_column) -> None: ...
    @property
    def fill_columns(self): ...
    @fill_columns.setter
    def fill_columns(self, fill_columns) -> None: ...
    @property
    def x_domain(self): ...
    @x_domain.setter
    def x_domain(self, x_domain) -> None: ...
    @property
    def x_axis_label(self): ...
    @x_axis_label.setter
    def x_axis_label(self, x_axis_label) -> None: ...
    @property
    def position(self): ...
    @position.setter
    def position(self, position) -> None: ...
    @property
    def bin_count(self): ...
    @bin_count.setter
    def bin_count(self, bin_count) -> None: ...
    @property
    def legend_colorize_rows(self): ...
    @legend_colorize_rows.setter
    def legend_colorize_rows(self, legend_colorize_rows) -> None: ...
    @property
    def legend_hide(self): ...
    @legend_hide.setter
    def legend_hide(self, legend_hide) -> None: ...
    @property
    def legend_opacity(self): ...
    @legend_opacity.setter
    def legend_opacity(self, legend_opacity) -> None: ...
    @property
    def legend_orientation_threshold(self): ...
    @legend_orientation_threshold.setter
    def legend_orientation_threshold(self, legend_orientation_threshold) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TemplateSummaryDiffChecks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        kind: Incomplete | None = None,
        state_status: Incomplete | None = None,
        id: Incomplete | None = None,
        template_meta_name: Incomplete | None = None,
        new: Incomplete | None = None,
        old: Incomplete | None = None,
    ) -> None: ...
    @property
    def kind(self): ...
    @kind.setter
    def kind(self, kind) -> None: ...
    @property
    def state_status(self): ...
    @state_status.setter
    def state_status(self, state_status) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def template_meta_name(self): ...
    @template_meta_name.setter
    def template_meta_name(self, template_meta_name) -> None: ...
    @property
    def new(self): ...
    @new.setter
    def new(self, new) -> None: ...
    @property
    def old(self): ...
    @old.setter
    def old(self, old) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Source:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        links: Incomplete | None = None,
        id: Incomplete | None = None,
        org_id: Incomplete | None = None,
        default: Incomplete | None = None,
        name: Incomplete | None = None,
        type: Incomplete | None = None,
        url: Incomplete | None = None,
        insecure_skip_verify: Incomplete | None = None,
        telegraf: Incomplete | None = None,
        token: Incomplete | None = None,
        username: Incomplete | None = None,
        password: Incomplete | None = None,
        shared_secret: Incomplete | None = None,
        meta_url: Incomplete | None = None,
        default_rp: Incomplete | None = None,
        languages: Incomplete | None = None,
    ) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def default(self): ...
    @default.setter
    def default(self, default) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def url(self): ...
    @url.setter
    def url(self, url) -> None: ...
    @property
    def insecure_skip_verify(self): ...
    @insecure_skip_verify.setter
    def insecure_skip_verify(self, insecure_skip_verify) -> None: ...
    @property
    def telegraf(self): ...
    @telegraf.setter
    def telegraf(self, telegraf) -> None: ...
    @property
    def token(self): ...
    @token.setter
    def token(self, token) -> None: ...
    @property
    def username(self): ...
    @username.setter
    def username(self, username) -> None: ...
    @property
    def password(self): ...
    @password.setter
    def password(self, password) -> None: ...
    @property
    def shared_secret(self): ...
    @shared_secret.setter
    def shared_secret(self, shared_secret) -> None: ...
    @property
    def meta_url(self): ...
    @meta_url.setter
    def meta_url(self, meta_url) -> None: ...
    @property
    def default_rp(self): ...
    @default_rp.setter
    def default_rp(self, default_rp) -> None: ...
    @property
    def languages(self): ...
    @languages.setter
    def languages(self, languages) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class AnalyzeQueryResponseErrors:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        line: Incomplete | None = None,
        column: Incomplete | None = None,
        character: Incomplete | None = None,
        message: Incomplete | None = None,
    ) -> None: ...
    @property
    def line(self): ...
    @line.setter
    def line(self, line) -> None: ...
    @property
    def column(self): ...
    @column.setter
    def column(self, column) -> None: ...
    @property
    def character(self): ...
    @character.setter
    def character(self, character) -> None: ...
    @property
    def message(self): ...
    @message.setter
    def message(self, message) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class BucketMetadataManifest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        organization_id: Incomplete | None = None,
        organization_name: Incomplete | None = None,
        bucket_id: Incomplete | None = None,
        bucket_name: Incomplete | None = None,
        description: Incomplete | None = None,
        default_retention_policy: Incomplete | None = None,
        retention_policies: Incomplete | None = None,
    ) -> None: ...
    @property
    def organization_id(self): ...
    @organization_id.setter
    def organization_id(self, organization_id) -> None: ...
    @property
    def organization_name(self): ...
    @organization_name.setter
    def organization_name(self, organization_name) -> None: ...
    @property
    def bucket_id(self): ...
    @bucket_id.setter
    def bucket_id(self, bucket_id) -> None: ...
    @property
    def bucket_name(self): ...
    @bucket_name.setter
    def bucket_name(self, bucket_name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def default_retention_policy(self): ...
    @default_retention_policy.setter
    def default_retention_policy(self, default_retention_policy) -> None: ...
    @property
    def retention_policies(self): ...
    @retention_policies.setter
    def retention_policies(self, retention_policies) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from typing import Any, ClassVar
from typing_extensions import Final, Literal, TypeAlias

_WritePrecision: TypeAlias = Literal["ms", "s", "us", "ns"]  # noqa: Y047

class WritePrecision:
    MS: Final = "ms"
    S: Final = "s"
    US: Final = "us"
    NS: Final = "ns"
    openapi_types: ClassVar[dict[str, Incomplete]]
    attribute_map: ClassVar[dict[str, Incomplete]]
    def __init__(self) -> None: ...
    def to_dict(self) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



from _typeshed import Incomplete

class HealthCheck:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        name: Incomplete | None = None,
        message: Incomplete | None = None,
        checks: Incomplete | None = None,
        status: Incomplete | None = None,
        version: Incomplete | None = None,
        commit: Incomplete | None = None,
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def message(self): ...
    @message.setter
    def message(self, message) -> None: ...
    @property
    def checks(self): ...
    @checks.setter
    def checks(self, checks) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def version(self): ...
    @version.setter
    def version(self, version) -> None: ...
    @property
    def commit(self): ...
    @commit.setter
    def commit(self, commit) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from collections.abc import Generator
from enum import Enum
from types import TracebackType
from typing_extensions import Self

from influxdb_client.client.flux_table import TableList

ANNOTATION_DEFAULT: str
ANNOTATION_GROUP: str
ANNOTATION_DATATYPE: str
ANNOTATIONS: Incomplete

class FluxQueryException(Exception):
    message: Incomplete
    reference: Incomplete
    def __init__(self, message, reference) -> None: ...

class FluxCsvParserException(Exception): ...

class FluxSerializationMode(Enum):
    tables: int
    stream: int
    dataFrame: int

class FluxResponseMetadataMode(Enum):
    full: int
    only_names: int

class _FluxCsvParserMetadata:
    table_index: int
    table_id: int
    start_new_table: bool
    table: Incomplete
    groups: Incomplete
    parsing_state_error: bool
    def __init__(self) -> None: ...

class FluxCsvParser:
    tables: Incomplete
    def __init__(
        self,
        response,
        serialization_mode: FluxSerializationMode,
        data_frame_index: list[str] | None = None,
        query_options: Incomplete | None = None,
        response_metadata_mode: FluxResponseMetadataMode = ...,
    ) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> None: ...
    async def __aenter__(self) -> Self: ...
    async def __aexit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> None: ...
    def generator(self) -> Generator[Incomplete, None, None]: ...
    def generator_async(self): ...
    def parse_record(self, table_index, table, csv): ...
    @staticmethod
    def add_data_types(table, data_types) -> None: ...
    @staticmethod
    def add_groups(table, csv) -> None: ...
    @staticmethod
    def add_default_empty_values(table, default_values) -> None: ...
    @staticmethod
    def add_column_names_and_tags(table, csv) -> None: ...
    def table_list(self) -> TableList: ...

class _StreamReaderToWithAsyncRead:
    response: Incomplete
    decoder: Incomplete
    def __init__(self, response) -> None: ...
    async def read(self, size: int) -> str: ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class BucketsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_buckets_id(self, bucket_id, **kwargs): ...
    def delete_buckets_id_with_http_info(self, bucket_id, **kwargs): ...
    async def delete_buckets_id_async(self, bucket_id, **kwargs): ...
    def delete_buckets_id_labels_id(self, bucket_id, label_id, **kwargs): ...
    def delete_buckets_id_labels_id_with_http_info(self, bucket_id, label_id, **kwargs): ...
    async def delete_buckets_id_labels_id_async(self, bucket_id, label_id, **kwargs): ...
    def delete_buckets_id_members_id(self, user_id, bucket_id, **kwargs): ...
    def delete_buckets_id_members_id_with_http_info(self, user_id, bucket_id, **kwargs): ...
    async def delete_buckets_id_members_id_async(self, user_id, bucket_id, **kwargs): ...
    def delete_buckets_id_owners_id(self, user_id, bucket_id, **kwargs): ...
    def delete_buckets_id_owners_id_with_http_info(self, user_id, bucket_id, **kwargs): ...
    async def delete_buckets_id_owners_id_async(self, user_id, bucket_id, **kwargs): ...
    def get_buckets(self, **kwargs): ...
    def get_buckets_with_http_info(self, **kwargs): ...
    async def get_buckets_async(self, **kwargs): ...
    def get_buckets_id(self, bucket_id, **kwargs): ...
    def get_buckets_id_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_async(self, bucket_id, **kwargs): ...
    def get_buckets_id_labels(self, bucket_id, **kwargs): ...
    def get_buckets_id_labels_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_labels_async(self, bucket_id, **kwargs): ...
    def get_buckets_id_members(self, bucket_id, **kwargs): ...
    def get_buckets_id_members_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_members_async(self, bucket_id, **kwargs): ...
    def get_buckets_id_owners(self, bucket_id, **kwargs): ...
    def get_buckets_id_owners_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_owners_async(self, bucket_id, **kwargs): ...
    def get_sources_id_buckets(self, source_id, **kwargs): ...
    def get_sources_id_buckets_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_buckets_async(self, source_id, **kwargs): ...
    def patch_buckets_id(self, bucket_id, patch_bucket_request, **kwargs): ...
    def patch_buckets_id_with_http_info(self, bucket_id, patch_bucket_request, **kwargs): ...
    async def patch_buckets_id_async(self, bucket_id, patch_bucket_request, **kwargs): ...
    def post_buckets(self, post_bucket_request, **kwargs): ...
    def post_buckets_with_http_info(self, post_bucket_request, **kwargs): ...
    async def post_buckets_async(self, post_bucket_request, **kwargs): ...
    def post_buckets_id_labels(self, bucket_id, label_mapping, **kwargs): ...
    def post_buckets_id_labels_with_http_info(self, bucket_id, label_mapping, **kwargs): ...
    async def post_buckets_id_labels_async(self, bucket_id, label_mapping, **kwargs): ...
    def post_buckets_id_members(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    def post_buckets_id_members_with_http_info(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    async def post_buckets_id_members_async(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    def post_buckets_id_owners(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    def post_buckets_id_owners_with_http_info(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    async def post_buckets_id_owners_async(self, bucket_id, add_resource_member_request_body, **kwargs): ...



from _typeshed import Incomplete

class Replication:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        id: Incomplete | None = None,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        org_id: Incomplete | None = None,
        remote_id: Incomplete | None = None,
        local_bucket_id: Incomplete | None = None,
        remote_bucket_id: Incomplete | None = None,
        remote_bucket_name: str | None = None,
        max_queue_size_bytes: Incomplete | None = None,
        current_queue_size_bytes: Incomplete | None = None,
        remaining_bytes_to_be_synced: int | None = None,
        latest_response_code: Incomplete | None = None,
        latest_error_message: Incomplete | None = None,
        drop_non_retryable_data: Incomplete | None = None,
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def remote_id(self): ...
    @remote_id.setter
    def remote_id(self, remote_id) -> None: ...
    @property
    def local_bucket_id(self): ...
    @local_bucket_id.setter
    def local_bucket_id(self, local_bucket_id) -> None: ...
    @property
    def remote_bucket_id(self): ...
    @remote_bucket_id.setter
    def remote_bucket_id(self, remote_bucket_id) -> None: ...
    remote_bucket_name: str | None
    @property
    def max_queue_size_bytes(self): ...
    @max_queue_size_bytes.setter
    def max_queue_size_bytes(self, max_queue_size_bytes) -> None: ...
    @property
    def current_queue_size_bytes(self): ...
    @current_queue_size_bytes.setter
    def current_queue_size_bytes(self, current_queue_size_bytes) -> None: ...
    remaining_bytes_to_be_synced: int | None
    @property
    def latest_response_code(self): ...
    @latest_response_code.setter
    def latest_response_code(self, latest_response_code) -> None: ...
    @property
    def latest_error_message(self): ...
    @latest_error_message.setter
    def latest_error_message(self, latest_error_message) -> None: ...
    @property
    def drop_non_retryable_data(self): ...
    @drop_non_retryable_data.setter
    def drop_non_retryable_data(self, drop_non_retryable_data) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class InvokableScriptsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_scripts_id(self, script_id, **kwargs): ...
    def delete_scripts_id_with_http_info(self, script_id, **kwargs): ...
    async def delete_scripts_id_async(self, script_id, **kwargs): ...
    def get_scripts(self, **kwargs): ...
    def get_scripts_with_http_info(self, **kwargs): ...
    async def get_scripts_async(self, **kwargs): ...
    def get_scripts_id(self, script_id, **kwargs): ...
    def get_scripts_id_with_http_info(self, script_id, **kwargs): ...
    async def get_scripts_id_async(self, script_id, **kwargs): ...
    def get_scripts_id_params(self, script_id, **kwargs): ...
    def get_scripts_id_params_with_http_info(self, script_id, **kwargs): ...
    async def get_scripts_id_params_async(self, script_id, **kwargs): ...
    def patch_scripts_id(self, script_id, script_update_request, **kwargs): ...
    def patch_scripts_id_with_http_info(self, script_id, script_update_request, **kwargs): ...
    async def patch_scripts_id_async(self, script_id, script_update_request, **kwargs): ...
    def post_scripts(self, script_create_request, **kwargs): ...
    def post_scripts_with_http_info(self, script_create_request, **kwargs): ...
    async def post_scripts_async(self, script_create_request, **kwargs): ...
    def post_scripts_id_invoke(self, script_id, **kwargs): ...
    def post_scripts_id_invoke_with_http_info(self, script_id, **kwargs): ...
    async def post_scripts_id_invoke_async(self, script_id, **kwargs): ...



from _typeshed import Incomplete

class Stack:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        id: Incomplete | None = None,
        org_id: Incomplete | None = None,
        created_at: Incomplete | None = None,
        events: Incomplete | None = None,
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def created_at(self): ...
    @created_at.setter
    def created_at(self, created_at) -> None: ...
    @property
    def events(self): ...
    @events.setter
    def events(self, events) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class RestoreService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def post_restore_bucket_id(self, bucket_id, body, **kwargs): ...
    def post_restore_bucket_id_with_http_info(self, bucket_id, body, **kwargs): ...
    async def post_restore_bucket_id_async(self, bucket_id, body, **kwargs): ...
    def post_restore_bucket_metadata(self, bucket_metadata_manifest, **kwargs): ...
    def post_restore_bucket_metadata_with_http_info(self, bucket_metadata_manifest, **kwargs): ...
    async def post_restore_bucket_metadata_async(self, bucket_metadata_manifest, **kwargs): ...
    def post_restore_kv(self, body, **kwargs): ...
    def post_restore_kv_with_http_info(self, body, **kwargs): ...
    async def post_restore_kv_async(self, body, **kwargs): ...
    def post_restore_shard_id(self, shard_id, body, **kwargs): ...
    def post_restore_shard_id_with_http_info(self, shard_id, body, **kwargs): ...
    async def post_restore_shard_id_async(self, shard_id, body, **kwargs): ...
    def post_restore_sql(self, body, **kwargs): ...
    def post_restore_sql_with_http_info(self, body, **kwargs): ...
    async def post_restore_sql_async(self, body, **kwargs): ...



from _typeshed import Incomplete

from influxdb_client.domain.user_response import UserResponse

class ResourceMember(UserResponse):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        role: str = "member",
        id: Incomplete | None = None,
        name: Incomplete | None = None,
        status: str = "active",
        links: Incomplete | None = None,
    ) -> None: ...
    @property
    def role(self): ...
    @role.setter
    def role(self, role) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Ready:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, status: Incomplete | None = None, started: Incomplete | None = None, up: Incomplete | None = None
    ) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def started(self): ...
    @started.setter
    def started(self, started) -> None: ...
    @property
    def up(self): ...
    @up.setter
    def up(self, up) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class SubscriptionManifest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, name: Incomplete | None = None, mode: Incomplete | None = None, destinations: Incomplete | None = None
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def mode(self): ...
    @mode.setter
    def mode(self, mode) -> None: ...
    @property
    def destinations(self): ...
    @destinations.setter
    def destinations(self, destinations) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class BucketShardMapping:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, old_id: Incomplete | None = None, new_id: Incomplete | None = None) -> None: ...
    @property
    def old_id(self): ...
    @old_id.setter
    def old_id(self, old_id) -> None: ...
    @property
    def new_id(self): ...
    @new_id.setter
    def new_id(self, new_id) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class ApiClient:
    PRIMITIVE_TYPES: Incomplete
    NATIVE_TYPES_MAPPING: Incomplete
    configuration: Incomplete
    pool_threads: Incomplete
    rest_client: Incomplete
    default_headers: Incomplete
    cookie: Incomplete
    def __init__(
        self,
        configuration: Incomplete | None = None,
        header_name: Incomplete | None = None,
        header_value: Incomplete | None = None,
        cookie: Incomplete | None = None,
        pool_threads: Incomplete | None = None,
        retries: bool = False,
    ) -> None: ...
    def __del__(self) -> None: ...
    @property
    def pool(self): ...
    @property
    def user_agent(self): ...
    @user_agent.setter
    def user_agent(self, value) -> None: ...
    def set_default_header(self, header_name, header_value) -> None: ...
    def sanitize_for_serialization(self, obj): ...
    def deserialize(self, response, response_type): ...
    def call_api(
        self,
        resource_path,
        method,
        path_params: Incomplete | None = None,
        query_params: Incomplete | None = None,
        header_params: Incomplete | None = None,
        body: Incomplete | None = None,
        post_params: Incomplete | None = None,
        files: Incomplete | None = None,
        response_type: Incomplete | None = None,
        auth_settings: Incomplete | None = None,
        async_req: Incomplete | None = None,
        _return_http_data_only: Incomplete | None = None,
        collection_formats: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
        urlopen_kw: Incomplete | None = None,
    ): ...
    def request(
        self,
        method,
        url,
        query_params: Incomplete | None = None,
        headers: Incomplete | None = None,
        post_params: Incomplete | None = None,
        body: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
        **urlopen_kw,
    ): ...
    def parameters_to_tuples(self, params, collection_formats): ...
    def prepare_post_parameters(self, post_params: Incomplete | None = None, files: Incomplete | None = None): ...
    def select_header_accept(self, accepts): ...
    def select_header_content_type(self, content_types): ...
    def update_params_for_auth(self, headers, querys, auth_settings) -> None: ...



from _typeshed import Incomplete

from urllib3 import HTTPResponse

logger: Incomplete

class InfluxDBError(Exception):
    response: Incomplete
    message: Incomplete
    retry_after: Incomplete
    def __init__(self, response: HTTPResponse | None = None, message: str | None = None) -> None: ...



from _typeshed import Incomplete

class ThresholdBase:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, level: Incomplete | None = None, all_values: Incomplete | None = None) -> None: ...
    @property
    def level(self): ...
    @level.setter
    def level(self, level) -> None: ...
    @property
    def all_values(self): ...
    @all_values.setter
    def all_values(self, all_values) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Routes:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        authorizations: Incomplete | None = None,
        buckets: Incomplete | None = None,
        dashboards: Incomplete | None = None,
        external: Incomplete | None = None,
        variables: Incomplete | None = None,
        me: Incomplete | None = None,
        flags: Incomplete | None = None,
        orgs: Incomplete | None = None,
        query: Incomplete | None = None,
        setup: Incomplete | None = None,
        signin: Incomplete | None = None,
        signout: Incomplete | None = None,
        sources: Incomplete | None = None,
        system: Incomplete | None = None,
        tasks: Incomplete | None = None,
        telegrafs: Incomplete | None = None,
        users: Incomplete | None = None,
        write: Incomplete | None = None,
    ) -> None: ...
    @property
    def authorizations(self): ...
    @authorizations.setter
    def authorizations(self, authorizations) -> None: ...
    @property
    def buckets(self): ...
    @buckets.setter
    def buckets(self, buckets) -> None: ...
    @property
    def dashboards(self): ...
    @dashboards.setter
    def dashboards(self, dashboards) -> None: ...
    @property
    def external(self): ...
    @external.setter
    def external(self, external) -> None: ...
    @property
    def variables(self): ...
    @variables.setter
    def variables(self, variables) -> None: ...
    @property
    def me(self): ...
    @me.setter
    def me(self, me) -> None: ...
    @property
    def flags(self): ...
    @flags.setter
    def flags(self, flags) -> None: ...
    @property
    def orgs(self): ...
    @orgs.setter
    def orgs(self, orgs) -> None: ...
    @property
    def query(self): ...
    @query.setter
    def query(self, query) -> None: ...
    @property
    def setup(self): ...
    @setup.setter
    def setup(self, setup) -> None: ...
    @property
    def signin(self): ...
    @signin.setter
    def signin(self, signin) -> None: ...
    @property
    def signout(self): ...
    @signout.setter
    def signout(self, signout) -> None: ...
    @property
    def sources(self): ...
    @sources.setter
    def sources(self, sources) -> None: ...
    @property
    def system(self): ...
    @system.setter
    def system(self, system) -> None: ...
    @property
    def tasks(self): ...
    @tasks.setter
    def tasks(self, tasks) -> None: ...
    @property
    def telegrafs(self): ...
    @telegrafs.setter
    def telegrafs(self, telegrafs) -> None: ...
    @property
    def users(self): ...
    @users.setter
    def users(self, users) -> None: ...
    @property
    def write(self): ...
    @write.setter
    def write(self, write) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Package:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        path: Incomplete | None = None,
        package: Incomplete | None = None,
        files: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def path(self): ...
    @path.setter
    def path(self, path) -> None: ...
    @property
    def package(self): ...
    @package.setter
    def package(self, package) -> None: ...
    @property
    def files(self): ...
    @files.setter
    def files(self, files) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TemplateSummary:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        sources: Incomplete | None = None,
        stack_id: Incomplete | None = None,
        summary: Incomplete | None = None,
        diff: Incomplete | None = None,
        errors: Incomplete | None = None,
    ) -> None: ...
    @property
    def sources(self): ...
    @sources.setter
    def sources(self, sources) -> None: ...
    @property
    def stack_id(self): ...
    @stack_id.setter
    def stack_id(self, stack_id) -> None: ...
    @property
    def summary(self): ...
    @summary.setter
    def summary(self, summary) -> None: ...
    @property
    def diff(self): ...
    @diff.setter
    def diff(self, diff) -> None: ...
    @property
    def errors(self): ...
    @errors.setter
    def errors(self, errors) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class File:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        name: Incomplete | None = None,
        package: Incomplete | None = None,
        imports: Incomplete | None = None,
        body: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def package(self): ...
    @package.setter
    def package(self, package) -> None: ...
    @property
    def imports(self): ...
    @imports.setter
    def imports(self, imports) -> None: ...
    @property
    def body(self): ...
    @body.setter
    def body(self, body) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.domain.check_discriminator import CheckDiscriminator

class ThresholdCheck(CheckDiscriminator):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: str = "threshold",
        thresholds: Incomplete | None = None,
        every: Incomplete | None = None,
        offset: Incomplete | None = None,
        tags: Incomplete | None = None,
        status_message_template: Incomplete | None = None,
        id: Incomplete | None = None,
        name: Incomplete | None = None,
        org_id: Incomplete | None = None,
        task_id: Incomplete | None = None,
        owner_id: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        query: Incomplete | None = None,
        status: Incomplete | None = None,
        description: Incomplete | None = None,
        latest_completed: Incomplete | None = None,
        last_run_status: Incomplete | None = None,
        last_run_error: Incomplete | None = None,
        labels: Incomplete | None = None,
        links: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def thresholds(self): ...
    @thresholds.setter
    def thresholds(self, thresholds) -> None: ...
    @property
    def every(self): ...
    @every.setter
    def every(self, every) -> None: ...
    @property
    def offset(self): ...
    @offset.setter
    def offset(self, offset) -> None: ...
    @property
    def tags(self): ...
    @tags.setter
    def tags(self, tags) -> None: ...
    @property
    def status_message_template(self): ...
    @status_message_template.setter
    def status_message_template(self, status_message_template) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TemplateApplyRemotes:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, url: Incomplete | None = None, content_type: Incomplete | None = None) -> None: ...
    @property
    def url(self): ...
    @url.setter
    def url(self, url) -> None: ...
    @property
    def content_type(self): ...
    @content_type.setter
    def content_type(self, content_type) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class CheckViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        adaptive_zoom_hide: bool | None = None,
        type: Incomplete | None = None,
        shape: Incomplete | None = None,
        check_id: Incomplete | None = None,
        check: Incomplete | None = None,
        queries: Incomplete | None = None,
        colors: Incomplete | None = None,
        legend_colorize_rows: Incomplete | None = None,
        legend_hide: Incomplete | None = None,
        legend_opacity: Incomplete | None = None,
        legend_orientation_threshold: Incomplete | None = None,
    ) -> None: ...
    adaptive_zoom_hide: bool | None
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def check_id(self): ...
    @check_id.setter
    def check_id(self, check_id) -> None: ...
    @property
    def check(self): ...
    @check.setter
    def check(self, check) -> None: ...
    @property
    def queries(self): ...
    @queries.setter
    def queries(self, queries) -> None: ...
    @property
    def colors(self): ...
    @colors.setter
    def colors(self, colors) -> None: ...
    @property
    def legend_colorize_rows(self): ...
    @legend_colorize_rows.setter
    def legend_colorize_rows(self, legend_colorize_rows) -> None: ...
    @property
    def legend_hide(self): ...
    @legend_hide.setter
    def legend_hide(self, legend_hide) -> None: ...
    @property
    def legend_opacity(self): ...
    @legend_opacity.setter
    def legend_opacity(self, legend_opacity) -> None: ...
    @property
    def legend_orientation_threshold(self): ...
    @legend_orientation_threshold.setter
    def legend_orientation_threshold(self, legend_orientation_threshold) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from influxdb_client import Label

class LabelsApi:
    def __init__(self, influxdb_client) -> None: ...
    def create_label(self, name: str, org_id: str, properties: dict[str, str] | None = None) -> Label: ...
    def update_label(self, label: Label): ...
    def delete_label(self, label: str | Label): ...
    def clone_label(self, cloned_name: str, label: Label) -> Label: ...
    def find_labels(self, **kwargs) -> list[Label]: ...
    def find_label_by_id(self, label_id: str): ...
    def find_label_by_org(self, org_id) -> list[Label]: ...



from _typeshed import Incomplete

class User:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, id: Incomplete | None = None, name: Incomplete | None = None, status: str = "active") -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TemplateApplyTemplate:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, content_type: Incomplete | None = None, sources: Incomplete | None = None, contents: Incomplete | None = None
    ) -> None: ...
    @property
    def content_type(self): ...
    @content_type.setter
    def content_type(self, content_type) -> None: ...
    @property
    def sources(self): ...
    @sources.setter
    def sources(self, sources) -> None: ...
    @property
    def contents(self): ...
    @contents.setter
    def contents(self, contents) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TaskCreateRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        org_id: Incomplete | None = None,
        org: Incomplete | None = None,
        status: Incomplete | None = None,
        flux: Incomplete | None = None,
        description: Incomplete | None = None,
    ) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def org(self): ...
    @org.setter
    def org(self, org) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def flux(self): ...
    @flux.setter
    def flux(self, flux) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.domain.notification_endpoint_discriminator import NotificationEndpointDiscriminator

class TelegramNotificationEndpoint(NotificationEndpointDiscriminator):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        token: Incomplete | None = None,
        channel: Incomplete | None = None,
        id: Incomplete | None = None,
        org_id: Incomplete | None = None,
        user_id: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        description: Incomplete | None = None,
        name: Incomplete | None = None,
        status: str = "active",
        labels: Incomplete | None = None,
        links: Incomplete | None = None,
        type: str = "telegram",
    ) -> None: ...
    @property
    def token(self): ...
    @token.setter
    def token(self, token) -> None: ...
    @property
    def channel(self): ...
    @channel.setter
    def channel(self, channel) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class SetupService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_setup(self, **kwargs): ...
    def get_setup_with_http_info(self, **kwargs): ...
    async def get_setup_async(self, **kwargs): ...
    def post_setup(self, onboarding_request, **kwargs): ...
    def post_setup_with_http_info(self, onboarding_request, **kwargs): ...
    async def post_setup_async(self, onboarding_request, **kwargs): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class RulesService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_notification_rules_id_query(self, rule_id, **kwargs): ...
    def get_notification_rules_id_query_with_http_info(self, rule_id, **kwargs): ...
    async def get_notification_rules_id_query_async(self, rule_id, **kwargs): ...



from setuptools import setup

name = "types-influxdb-client"
description = "Typing stubs for influxdb-client"
long_description = '''
## Typing stubs for influxdb-client

This is a PEP 561 type stub package for the `influxdb-client` package. It
can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
PyCharm, etc. to check code that uses
`influxdb-client`. The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/influxdb-client. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit `695d41f4870aede6e7027cf23bb65b07b59eedc6` and was tested
with mypy 1.4.1, pyright 1.1.323, and
pytype 2023.8.14.
'''.lstrip()

setup(name=name,
      version="1.37.0.0",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/influxdb-client.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=['types-urllib3'],
      packages=['influxdb_client-stubs'],
      package_data={'influxdb_client-stubs': ['__init__.pyi', '_async/__init__.pyi', '_async/api_client.pyi', '_async/rest.pyi', '_sync/__init__.pyi', '_sync/api_client.pyi', '_sync/rest.pyi', 'client/__init__.pyi', 'client/_base.pyi', 'client/authorizations_api.pyi', 'client/bucket_api.pyi', 'client/delete_api.pyi', 'client/delete_api_async.pyi', 'client/exceptions.pyi', 'client/flux_csv_parser.pyi', 'client/flux_table.pyi', 'client/influxdb_client.pyi', 'client/influxdb_client_async.pyi', 'client/invokable_scripts_api.pyi', 'client/labels_api.pyi', 'client/logging_handler.pyi', 'client/organizations_api.pyi', 'client/query_api.pyi', 'client/query_api_async.pyi', 'client/tasks_api.pyi', 'client/users_api.pyi', 'client/util/__init__.pyi', 'client/util/date_utils.pyi', 'client/util/date_utils_pandas.pyi', 'client/util/helpers.pyi', 'client/util/multiprocessing_helper.pyi', 'client/warnings.pyi', 'client/write/__init__.pyi', 'client/write/dataframe_serializer.pyi', 'client/write/point.pyi', 'client/write/retry.pyi', 'client/write_api.pyi', 'client/write_api_async.pyi', 'configuration.pyi', 'domain/__init__.pyi', 'domain/add_resource_member_request_body.pyi', 'domain/analyze_query_response.pyi', 'domain/analyze_query_response_errors.pyi', 'domain/array_expression.pyi', 'domain/ast_response.pyi', 'domain/authorization.pyi', 'domain/authorization_post_request.pyi', 'domain/authorization_update_request.pyi', 'domain/authorizations.pyi', 'domain/axes.pyi', 'domain/axis.pyi', 'domain/axis_scale.pyi', 'domain/bad_statement.pyi', 'domain/band_view_properties.pyi', 'domain/binary_expression.pyi', 'domain/block.pyi', 'domain/boolean_literal.pyi', 'domain/bucket.pyi', 'domain/bucket_links.pyi', 'domain/bucket_metadata_manifest.pyi', 'domain/bucket_retention_rules.pyi', 'domain/bucket_shard_mapping.pyi', 'domain/buckets.pyi', 'domain/builder_aggregate_function_type.pyi', 'domain/builder_config.pyi', 'domain/builder_config_aggregate_window.pyi', 'domain/builder_functions_type.pyi', 'domain/builder_tags_type.pyi', 'domain/builtin_statement.pyi', 'domain/call_expression.pyi', 'domain/cell.pyi', 'domain/cell_links.pyi', 'domain/cell_update.pyi', 'domain/cell_with_view_properties.pyi', 'domain/check.pyi', 'domain/check_base.pyi', 'domain/check_base_links.pyi', 'domain/check_discriminator.pyi', 'domain/check_patch.pyi', 'domain/check_status_level.pyi', 'domain/check_view_properties.pyi', 'domain/checks.pyi', 'domain/column_data_type.pyi', 'domain/column_semantic_type.pyi', 'domain/conditional_expression.pyi', 'domain/config.pyi', 'domain/constant_variable_properties.pyi', 'domain/create_cell.pyi', 'domain/create_dashboard_request.pyi', 'domain/custom_check.pyi', 'domain/dashboard.pyi', 'domain/dashboard_color.pyi', 'domain/dashboard_query.pyi', 'domain/dashboard_with_view_properties.pyi', 'domain/dashboards.pyi', 'domain/date_time_literal.pyi', 'domain/dbr_ps.pyi', 'domain/dbrp.pyi', 'domain/dbrp_create.pyi', 'domain/dbrp_get.pyi', 'domain/dbrp_update.pyi', 'domain/deadman_check.pyi', 'domain/decimal_places.pyi', 'domain/delete_predicate_request.pyi', 'domain/dialect.pyi', 'domain/dict_expression.pyi', 'domain/dict_item.pyi', 'domain/duration.pyi', 'domain/duration_literal.pyi', 'domain/error.pyi', 'domain/expression.pyi', 'domain/expression_statement.pyi', 'domain/field.pyi', 'domain/file.pyi', 'domain/float_literal.pyi', 'domain/flux_response.pyi', 'domain/flux_suggestion.pyi', 'domain/flux_suggestions.pyi', 'domain/function_expression.pyi', 'domain/gauge_view_properties.pyi', 'domain/greater_threshold.pyi', 'domain/health_check.pyi', 'domain/heatmap_view_properties.pyi', 'domain/histogram_view_properties.pyi', 'domain/http_notification_endpoint.pyi', 'domain/http_notification_rule.pyi', 'domain/http_notification_rule_base.pyi', 'domain/identifier.pyi', 'domain/import_declaration.pyi', 'domain/index_expression.pyi', 'domain/integer_literal.pyi', 'domain/is_onboarding.pyi', 'domain/label.pyi', 'domain/label_create_request.pyi', 'domain/label_mapping.pyi', 'domain/label_response.pyi', 'domain/label_update.pyi', 'domain/labels_response.pyi', 'domain/language_request.pyi', 'domain/legacy_authorization_post_request.pyi', 'domain/lesser_threshold.pyi', 'domain/line_plus_single_stat_properties.pyi', 'domain/line_protocol_error.pyi', 'domain/line_protocol_length_error.pyi', 'domain/links.pyi', 'domain/list_stacks_response.pyi', 'domain/log_event.pyi', 'domain/logical_expression.pyi', 'domain/logs.pyi', 'domain/map_variable_properties.pyi', 'domain/markdown_view_properties.pyi', 'domain/measurement_schema.pyi', 'domain/measurement_schema_column.pyi', 'domain/measurement_schema_create_request.pyi', 'domain/measurement_schema_list.pyi', 'domain/measurement_schema_update_request.pyi', 'domain/member_assignment.pyi', 'domain/member_expression.pyi', 'domain/metadata_backup.pyi', 'domain/model_property.pyi', 'domain/mosaic_view_properties.pyi', 'domain/node.pyi', 'domain/notification_endpoint.pyi', 'domain/notification_endpoint_base.pyi', 'domain/notification_endpoint_base_links.pyi', 'domain/notification_endpoint_discriminator.pyi', 'domain/notification_endpoint_type.pyi', 'domain/notification_endpoint_update.pyi', 'domain/notification_endpoints.pyi', 'domain/notification_rule.pyi', 'domain/notification_rule_base.pyi', 'domain/notification_rule_base_links.pyi', 'domain/notification_rule_discriminator.pyi', 'domain/notification_rule_update.pyi', 'domain/notification_rules.pyi', 'domain/object_expression.pyi', 'domain/onboarding_request.pyi', 'domain/onboarding_response.pyi', 'domain/option_statement.pyi', 'domain/organization.pyi', 'domain/organization_links.pyi', 'domain/organizations.pyi', 'domain/package.pyi', 'domain/package_clause.pyi', 'domain/pager_duty_notification_endpoint.pyi', 'domain/pager_duty_notification_rule.pyi', 'domain/pager_duty_notification_rule_base.pyi', 'domain/paren_expression.pyi', 'domain/password_reset_body.pyi', 'domain/patch_bucket_request.pyi', 'domain/patch_dashboard_request.pyi', 'domain/patch_organization_request.pyi', 'domain/patch_retention_rule.pyi', 'domain/patch_stack_request.pyi', 'domain/patch_stack_request_additional_resources.pyi', 'domain/permission.pyi', 'domain/permission_resource.pyi', 'domain/pipe_expression.pyi', 'domain/pipe_literal.pyi', 'domain/post_bucket_request.pyi', 'domain/post_check.pyi', 'domain/post_notification_endpoint.pyi', 'domain/post_notification_rule.pyi', 'domain/post_organization_request.pyi', 'domain/post_restore_kv_response.pyi', 'domain/post_stack_request.pyi', 'domain/property_key.pyi', 'domain/query.pyi', 'domain/query_edit_mode.pyi', 'domain/query_variable_properties.pyi', 'domain/query_variable_properties_values.pyi', 'domain/range_threshold.pyi', 'domain/ready.pyi', 'domain/regexp_literal.pyi', 'domain/remote_connection.pyi', 'domain/remote_connection_creation_request.pyi', 'domain/remote_connection_update_request.pyi', 'domain/remote_connections.pyi', 'domain/renamable_field.pyi', 'domain/replication.pyi', 'domain/replication_creation_request.pyi', 'domain/replication_update_request.pyi', 'domain/replications.pyi', 'domain/resource_member.pyi', 'domain/resource_members.pyi', 'domain/resource_members_links.pyi', 'domain/resource_owner.pyi', 'domain/resource_owners.pyi', 'domain/restored_bucket_mappings.pyi', 'domain/retention_policy_manifest.pyi', 'domain/return_statement.pyi', 'domain/routes.pyi', 'domain/routes_external.pyi', 'domain/routes_query.pyi', 'domain/routes_system.pyi', 'domain/rule_status_level.pyi', 'domain/run.pyi', 'domain/run_links.pyi', 'domain/run_manually.pyi', 'domain/runs.pyi', 'domain/scatter_view_properties.pyi', 'domain/schema_type.pyi', 'domain/scraper_target_request.pyi', 'domain/scraper_target_response.pyi', 'domain/scraper_target_responses.pyi', 'domain/script.pyi', 'domain/script_create_request.pyi', 'domain/script_invocation_params.pyi', 'domain/script_language.pyi', 'domain/script_update_request.pyi', 'domain/scripts.pyi', 'domain/secret_keys.pyi', 'domain/secret_keys_response.pyi', 'domain/shard_group_manifest.pyi', 'domain/shard_manifest.pyi', 'domain/shard_owner.pyi', 'domain/simple_table_view_properties.pyi', 'domain/single_stat_view_properties.pyi', 'domain/slack_notification_endpoint.pyi', 'domain/slack_notification_rule.pyi', 'domain/slack_notification_rule_base.pyi', 'domain/smtp_notification_rule.pyi', 'domain/smtp_notification_rule_base.pyi', 'domain/source.pyi', 'domain/source_links.pyi', 'domain/sources.pyi', 'domain/stack.pyi', 'domain/stack_associations.pyi', 'domain/stack_events.pyi', 'domain/stack_links.pyi', 'domain/stack_resources.pyi', 'domain/statement.pyi', 'domain/static_legend.pyi', 'domain/status_rule.pyi', 'domain/string_literal.pyi', 'domain/subscription_manifest.pyi', 'domain/table_view_properties.pyi', 'domain/table_view_properties_table_options.pyi', 'domain/tag_rule.pyi', 'domain/task.pyi', 'domain/task_create_request.pyi', 'domain/task_links.pyi', 'domain/task_status_type.pyi', 'domain/task_update_request.pyi', 'domain/tasks.pyi', 'domain/telegraf.pyi', 'domain/telegraf_plugin.pyi', 'domain/telegraf_plugin_request.pyi', 'domain/telegraf_plugin_request_plugins.pyi', 'domain/telegraf_plugins.pyi', 'domain/telegraf_request.pyi', 'domain/telegraf_request_metadata.pyi', 'domain/telegrafs.pyi', 'domain/telegram_notification_endpoint.pyi', 'domain/telegram_notification_rule.pyi', 'domain/telegram_notification_rule_base.pyi', 'domain/template_apply.pyi', 'domain/template_apply_remotes.pyi', 'domain/template_apply_template.pyi', 'domain/template_chart.pyi', 'domain/template_export_by_id.pyi', 'domain/template_export_by_id_org_ids.pyi', 'domain/template_export_by_id_resource_filters.pyi', 'domain/template_export_by_id_resources.pyi', 'domain/template_export_by_name.pyi', 'domain/template_export_by_name_resources.pyi', 'domain/template_kind.pyi', 'domain/template_summary.pyi', 'domain/template_summary_diff.pyi', 'domain/template_summary_diff_buckets.pyi', 'domain/template_summary_diff_buckets_new_old.pyi', 'domain/template_summary_diff_checks.pyi', 'domain/template_summary_diff_dashboards.pyi', 'domain/template_summary_diff_dashboards_new_old.pyi', 'domain/template_summary_diff_label_mappings.pyi', 'domain/template_summary_diff_labels.pyi', 'domain/template_summary_diff_labels_new_old.pyi', 'domain/template_summary_diff_notification_endpoints.pyi', 'domain/template_summary_diff_notification_rules.pyi', 'domain/template_summary_diff_notification_rules_new_old.pyi', 'domain/template_summary_diff_tasks.pyi', 'domain/template_summary_diff_tasks_new_old.pyi', 'domain/template_summary_diff_telegraf_configs.pyi', 'domain/template_summary_diff_variables.pyi', 'domain/template_summary_diff_variables_new_old.pyi', 'domain/template_summary_errors.pyi', 'domain/template_summary_label.pyi', 'domain/template_summary_label_properties.pyi', 'domain/template_summary_summary.pyi', 'domain/template_summary_summary_buckets.pyi', 'domain/template_summary_summary_dashboards.pyi', 'domain/template_summary_summary_label_mappings.pyi', 'domain/template_summary_summary_notification_rules.pyi', 'domain/template_summary_summary_status_rules.pyi', 'domain/template_summary_summary_tag_rules.pyi', 'domain/template_summary_summary_tasks.pyi', 'domain/template_summary_summary_variables.pyi', 'domain/test_statement.pyi', 'domain/threshold.pyi', 'domain/threshold_base.pyi', 'domain/threshold_check.pyi', 'domain/unary_expression.pyi', 'domain/unsigned_integer_literal.pyi', 'domain/user.pyi', 'domain/user_response.pyi', 'domain/user_response_links.pyi', 'domain/users.pyi', 'domain/variable.pyi', 'domain/variable_assignment.pyi', 'domain/variable_links.pyi', 'domain/variable_properties.pyi', 'domain/variables.pyi', 'domain/view.pyi', 'domain/view_links.pyi', 'domain/view_properties.pyi', 'domain/views.pyi', 'domain/write_precision.pyi', 'domain/xy_geom.pyi', 'domain/xy_view_properties.pyi', 'extras.pyi', 'rest.pyi', 'service/__init__.pyi', 'service/_base_service.pyi', 'service/authorizations_service.pyi', 'service/backup_service.pyi', 'service/bucket_schemas_service.pyi', 'service/buckets_service.pyi', 'service/cells_service.pyi', 'service/checks_service.pyi', 'service/config_service.pyi', 'service/dashboards_service.pyi', 'service/dbr_ps_service.pyi', 'service/delete_service.pyi', 'service/health_service.pyi', 'service/invokable_scripts_service.pyi', 'service/labels_service.pyi', 'service/legacy_authorizations_service.pyi', 'service/metrics_service.pyi', 'service/notification_endpoints_service.pyi', 'service/notification_rules_service.pyi', 'service/organizations_service.pyi', 'service/ping_service.pyi', 'service/query_service.pyi', 'service/ready_service.pyi', 'service/remote_connections_service.pyi', 'service/replications_service.pyi', 'service/resources_service.pyi', 'service/restore_service.pyi', 'service/routes_service.pyi', 'service/rules_service.pyi', 'service/scraper_targets_service.pyi', 'service/secrets_service.pyi', 'service/setup_service.pyi', 'service/signin_service.pyi', 'service/signout_service.pyi', 'service/sources_service.pyi', 'service/tasks_service.pyi', 'service/telegraf_plugins_service.pyi', 'service/telegrafs_service.pyi', 'service/templates_service.pyi', 'service/users_service.pyi', 'service/variables_service.pyi', 'service/views_service.pyi', 'service/write_service.pyi', 'version.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)



from _typeshed import Incomplete

class OnboardingRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        username: Incomplete | None = None,
        password: Incomplete | None = None,
        org: Incomplete | None = None,
        bucket: Incomplete | None = None,
        retention_period_seconds: Incomplete | None = None,
        retention_period_hrs: Incomplete | None = None,
        token: Incomplete | None = None,
    ) -> None: ...
    @property
    def username(self): ...
    @username.setter
    def username(self, username) -> None: ...
    @property
    def password(self): ...
    @password.setter
    def password(self, password) -> None: ...
    @property
    def org(self): ...
    @org.setter
    def org(self, org) -> None: ...
    @property
    def bucket(self): ...
    @bucket.setter
    def bucket(self, bucket) -> None: ...
    @property
    def retention_period_seconds(self): ...
    @retention_period_seconds.setter
    def retention_period_seconds(self, retention_period_seconds) -> None: ...
    @property
    def retention_period_hrs(self): ...
    @retention_period_hrs.setter
    def retention_period_hrs(self, retention_period_hrs) -> None: ...
    @property
    def token(self): ...
    @token.setter
    def token(self, token) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Threshold:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator_value_class_map: Incomplete
    discriminator: str
    def __init__(self, type: Incomplete | None = None) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    def get_real_child_model(self, data): ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Cell:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        id: Incomplete | None = None,
        links: Incomplete | None = None,
        x: Incomplete | None = None,
        y: Incomplete | None = None,
        w: Incomplete | None = None,
        h: Incomplete | None = None,
        view_id: Incomplete | None = None,
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    @property
    def x(self): ...
    @x.setter
    def x(self, x) -> None: ...
    @property
    def y(self): ...
    @y.setter
    def y(self, y) -> None: ...
    @property
    def w(self): ...
    @w.setter
    def w(self, w) -> None: ...
    @property
    def h(self): ...
    @h.setter
    def h(self, h) -> None: ...
    @property
    def view_id(self): ...
    @view_id.setter
    def view_id(self, view_id) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class ResourceOwners:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, links: Incomplete | None = None, users: Incomplete | None = None) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    @property
    def users(self): ...
    @users.setter
    def users(self, users) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Axis:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        bounds: Incomplete | None = None,
        label: Incomplete | None = None,
        prefix: Incomplete | None = None,
        suffix: Incomplete | None = None,
        base: Incomplete | None = None,
        scale: Incomplete | None = None,
    ) -> None: ...
    @property
    def bounds(self): ...
    @bounds.setter
    def bounds(self, bounds) -> None: ...
    @property
    def label(self): ...
    @label.setter
    def label(self, label) -> None: ...
    @property
    def prefix(self): ...
    @prefix.setter
    def prefix(self, prefix) -> None: ...
    @property
    def suffix(self): ...
    @suffix.setter
    def suffix(self, suffix) -> None: ...
    @property
    def base(self): ...
    @base.setter
    def base(self, base) -> None: ...
    @property
    def scale(self): ...
    @scale.setter
    def scale(self, scale) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class StaticLegend:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        colorize_rows: Incomplete | None = None,
        height_ratio: Incomplete | None = None,
        show: Incomplete | None = None,
        opacity: Incomplete | None = None,
        orientation_threshold: Incomplete | None = None,
        value_axis: Incomplete | None = None,
        width_ratio: Incomplete | None = None,
    ) -> None: ...
    @property
    def colorize_rows(self): ...
    @colorize_rows.setter
    def colorize_rows(self, colorize_rows) -> None: ...
    @property
    def height_ratio(self): ...
    @height_ratio.setter
    def height_ratio(self, height_ratio) -> None: ...
    @property
    def show(self): ...
    @show.setter
    def show(self, show) -> None: ...
    @property
    def opacity(self): ...
    @opacity.setter
    def opacity(self, opacity) -> None: ...
    @property
    def orientation_threshold(self): ...
    @orientation_threshold.setter
    def orientation_threshold(self, orientation_threshold) -> None: ...
    @property
    def value_axis(self): ...
    @value_axis.setter
    def value_axis(self, value_axis) -> None: ...
    @property
    def width_ratio(self): ...
    @width_ratio.setter
    def width_ratio(self, width_ratio) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class BucketSchemasService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def create_measurement_schema(self, bucket_id, measurement_schema_create_request, **kwargs): ...
    def create_measurement_schema_with_http_info(self, bucket_id, measurement_schema_create_request, **kwargs): ...
    async def create_measurement_schema_async(self, bucket_id, measurement_schema_create_request, **kwargs): ...
    def get_measurement_schema(self, bucket_id, measurement_id, **kwargs): ...
    def get_measurement_schema_with_http_info(self, bucket_id, measurement_id, **kwargs): ...
    async def get_measurement_schema_async(self, bucket_id, measurement_id, **kwargs): ...
    def get_measurement_schemas(self, bucket_id, **kwargs): ...
    def get_measurement_schemas_with_http_info(self, bucket_id, **kwargs): ...
    async def get_measurement_schemas_async(self, bucket_id, **kwargs): ...
    def update_measurement_schema(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs): ...
    def update_measurement_schema_with_http_info(
        self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs
    ): ...
    async def update_measurement_schema_async(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs): ...
